@@ -24,8 +24,8 @@
 #include <config.h>
 #endif
 
-#include <QtCore/QString>
-#include <QtCore/QMap>
+#include <QString>
+#include <QMap>
 
 namespace SubtitleComposer {
 class FormatData
