@@ -26,9 +26,9 @@
 
 #include <climits>
 
-#include <QtCore/QList>
+#include <QList>
 
-#include <KDebug>
+#include <QDebug>
 
 namespace SubtitleComposer {
 class Range
