@@ -19,10 +19,12 @@
 
 #include "sstring.h"
 
-#include <QtCore/QList>
-#include <QtCore/QStringList>
+#include <QList>
+#include <QStringList>
 
-#include <KDebug>
+#include <QDebug>
+
+#include <QColor>
 
 using namespace SubtitleComposer;
 
@@ -263,26 +265,26 @@ SString::setRichString(const QString &string)
 		int newStyle = currentStyle;
 		QColor newColor(currentColor);
 
-		if(matched == "b") {
+		if(matched == QLatin1String("b")) {
 			newStyle |= SString::Bold;
-		} else if(matched == "i") {
+		} else if(matched == QLatin1String("i")) {
 			newStyle |= SString::Italic;
-		} else if(matched == "u") {
+		} else if(matched == QLatin1String("u")) {
 			newStyle |= SString::Underline;
-		} else if(matched == "s") {
+		} else if(matched == QLatin1String("s")) {
 			newStyle |= SString::StrikeThrough;
-		} else if(matched == "font") {
+		} else if(matched == QLatin1String("font")) {
 			newStyle |= SString::Color;
 			newColor.setNamedColor(tagRegExp.cap(4).toLower());
-		} else if(matched == "/b") {
+		} else if(matched == QLatin1String("/b")) {
 			newStyle &= ~SString::Bold;
-		} else if(matched == "/i") {
+		} else if(matched == QLatin1String("/i")) {
 			newStyle &= ~SString::Italic;
-		} else if(matched == "/u") {
+		} else if(matched == QLatin1String("/u")) {
 			newStyle &= ~SString::Underline;
-		} else if(matched == "/s") {
+		} else if(matched == QLatin1String("/s")) {
 			newStyle &= ~SString::StrikeThrough;
-		} else if(matched == "/font") {
+		} else if(matched == QLatin1String("/font")) {
 			newStyle &= ~SString::Color;
 			newColor.setNamedColor("-invalid-");
 		}
@@ -846,7 +848,7 @@ SString::replace(const QRegExp &rx, const QString &a)
 				escaping = false;
 				if(chr.isNumber()) {
 					int capNumber = chr.digitValue();
-					if(capNumber <= regExp.numCaptures()) {
+					if(capNumber <= regExp.captureCount()) {
 						QString cap(regExp.cap(capNumber));
 						after.replace(afterIndex - 1, 2, cap);
 						afterIndex = afterIndex - 1 + cap.length();
@@ -933,7 +935,7 @@ SString::replace(const QRegExp &rx, const SString &a)
 				escaping = false;
 				if(chr.isNumber()) {
 					int capNumber = chr.digitValue();
-					if(capNumber <= regExp.numCaptures()) {
+					if(capNumber <= regExp.captureCount()) {
 						QString cap(regExp.cap(capNumber));
 						after.replace(afterIndex - 1, 2, cap);
 						afterIndex = afterIndex - 1 + cap.length();
