@@ -26,12 +26,12 @@
 
 #include <string.h>
 
-#include <QtCore/QString>
-#include <QtCore/QRegExp>
-#include <QtCore/QList>
+#include <QString>
+#include <QRegExp>
+#include <QList>
 #include <QColor>
 
-#include <KDebug>
+#include <QDebug>
 
 void * memset_n(void *ptr, int value, size_t length, size_t size);
 
