@@ -388,6 +388,9 @@ Subtitle::removeAllAnchors()
 void
 Subtitle::insertLine(SubtitleLine *line, int index)
 {
+	if(index > 0)
+		setLastValidCachedIndex(index - 1);
+
 	QList<SubtitleLine *> lines;
 	lines.append(line);
 	insertLines(lines, index);
@@ -1414,14 +1417,20 @@ Subtitle::incrementState(int dirtyMode)
 			emit primaryDirtyStateChanged(true);
 		else if(m_primaryState == m_primaryCleanState)
 			emit primaryDirtyStateChanged(false);
+
+		emit primaryChanged();
 		break;
+
 	case SubtitleAction::Secondary:
 		m_secondaryState++;
 		if(m_secondaryState == (m_secondaryCleanState + 1))
 			emit secondaryDirtyStateChanged(true);
 		else if(m_secondaryState == m_secondaryCleanState)
 			emit secondaryDirtyStateChanged(false);
+
+		emit secondaryChanged();
 		break;
+
 	case SubtitleAction::Both:
 		m_primaryState++;
 		m_secondaryState++;
@@ -1433,8 +1442,9 @@ Subtitle::incrementState(int dirtyMode)
 			emit secondaryDirtyStateChanged(true);
 		else if(m_secondaryState == m_secondaryCleanState)
 			emit secondaryDirtyStateChanged(false);
-		break;
-	default:
+
+		emit primaryChanged();
+		emit secondaryChanged();
 		break;
 	}
 }
@@ -1449,14 +1459,20 @@ Subtitle::decrementState(int dirtyMode)
 			emit primaryDirtyStateChanged(false);
 		else if(m_primaryState == (m_primaryCleanState - 1))
 			emit primaryDirtyStateChanged(true);
+
+		emit primaryChanged();
 		break;
+
 	case SubtitleAction::Secondary:
 		m_secondaryState--;
 		if(m_secondaryState == m_secondaryCleanState)
 			emit secondaryDirtyStateChanged(false);
 		else if(m_secondaryState == (m_secondaryCleanState - 1))
 			emit secondaryDirtyStateChanged(true);
+
+		emit secondaryChanged();
 		break;
+
 	case SubtitleAction::Both:
 		m_primaryState--;
 		m_secondaryState--;
@@ -1468,6 +1484,9 @@ Subtitle::decrementState(int dirtyMode)
 			emit secondaryDirtyStateChanged(false);
 		else if(m_secondaryState == (m_secondaryCleanState - 1))
 			emit secondaryDirtyStateChanged(true);
+
+		emit primaryChanged();
+		emit secondaryChanged();
 		break;
 	}
 }
@@ -1496,18 +1515,18 @@ Subtitle::setLastValidCachedIndex(int lastValidCachedIndex)
 
 	m_lastValidCachedIndex = lastValidCachedIndex;
 
-	/*
-	   qDebug() << "last valid cached index" << m_lastValidCachedIndex;
+/*
+	qDebug() << "last valid cached index" << m_lastValidCachedIndex;
 
-	   QStringList cacheIndexList, indexList;
-	   for ( int lineIndex = 0, linesCount = m_lines.count(); lineIndex < linesCount; ++lineIndex )
-	   cacheIndexList << QString::number( m_lines.at( lineIndex )->m_cachedIndex );
-	   qDebug() << "cached indexes:" << cacheIndexList.join( " " );
+	QStringList cacheIndexList, indexList;
+	for ( int lineIndex = 0, linesCount = m_lines.count(); lineIndex < linesCount; ++lineIndex )
+	cacheIndexList << QString::number( m_lines.at( lineIndex )->m_cachedIndex );
+	qDebug() << "cached indexes:" << cacheIndexList.join( " " );
 
-	   for ( int lineIndex = 0, linesCount = m_lines.count(); lineIndex < linesCount; ++lineIndex )
-	   indexList << QString::number( m_lines.at( lineIndex )->index() );
-	   qDebug() << "indexes:" << indexList.join( " " );
-	 */
+	for ( int lineIndex = 0, linesCount = m_lines.count(); lineIndex < linesCount; ++lineIndex )
+	indexList << QString::number( m_lines.at( lineIndex )->index() );
+	qDebug() << "indexes:" << indexList.join( " " );
+//*/
 }
 
 /// SUBTITLECOMPOSITEACTIONEXECUTOR
