@@ -54,7 +54,7 @@ SubtitleLine::errorID(SubtitleLine::ErrorFlag flag)
 	if(flag < 1)
 		return ErrorUNKNOWN;
 
-	int id = (int)log2(flag);
+	int id = log2(static_cast<int>(flag));
 	return id < ErrorSIZE ? (ErrorID)id : ErrorUNKNOWN;
 }
 
@@ -242,9 +242,9 @@ SubtitleLine::index() const
 				break;
 			}
 		}
-//		qDebug() << "searched index";
+//		qDebug() << "searched index" << m_cachedIndex;
 	}
-//	qDebug() << "index" << m_index << "| text" << m_primaryText.string();
+//	qDebug() << "index" << m_cachedIndex << "| text" << m_primaryText.string();
 	return m_cachedIndex;
 }
 
