@@ -1,21 +1,22 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "formatmanager.h"
 #include "../common/fileloadhelper.h"
@@ -41,15 +42,13 @@
 #include "youtubecaptions/youtubecaptionsinputformat.h"
 #include "youtubecaptions/youtubecaptionsoutputformat.h"
 
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QTextCodec>
-#include <QtCore/QTextStream>
+#include <QFile>
+#include <QFileInfo>
+#include <QTextCodec>
+#include <QTextStream>
 
-#include <KDE/KGlobal>
-#include <KDE/KLocale>
-#include <KDE/KCharsets>
-#include <KDE/KUrl>
+#include <KCharsets>
+#include <QUrl>
 
 #include <unicode/ucsdet.h>
 
@@ -64,15 +63,15 @@ FormatManager::instance()
 
 FormatManager::FormatManager()
 {
-	/*foreach( const QStringList &encodingsForScript, KGlobal::charsets()->encodingsByScript() )
+	/*foreach( const QStringList &encodingsForScript, KCharsets::charsets()->encodingsByScript() )
 	   {
 	   KEncodingDetector::AutoDetectScript scri = KEncodingDetector::scriptForName( encodingsForScript.at( 0 ) );
 	   if ( KEncodingDetector::hasAutoDetectionForScript( scri ) )
-	   kDebug() << encodingsForScript.at( 0 ) << "[autodetect available]";
+	   qDebug() << encodingsForScript.at( 0 ) << "[autodetect available]";
 	   else
-	   kDebug() << encodingsForScript.at( 0 );
+	   qDebug() << encodingsForScript.at( 0 );
 	   for ( int i=1; i < encodingsForScript.size(); ++i )
-	   kDebug() << "-" << encodingsForScript.at( i );
+	   qDebug() << "-" << encodingsForScript.at( i );
 	   } */
 
 	InputFormat *inputFormats[] = {
@@ -140,12 +139,12 @@ FormatManager::inputNames() const
 }
 
 bool
-FormatManager::readSubtitle(Subtitle &subtitle, bool primary, const KUrl &url, KEncodingDetector::AutoDetectScript autodetectScript, QTextCodec **codec, Format::NewLine *newLine, QString *formatName) const
+FormatManager::readSubtitle(Subtitle &subtitle, bool primary, const QUrl &url, QTextCodec **codec, Format::NewLine *newLine, QString *formatName) const
 {
 //  if ( *codec )
-//      kDebug() << "loading" << url << "script" << autodetectScript << "codec" << (*codec)->name();
+//      qDebug() << "loading" << url << "script" << autodetectScript << "codec" << (*codec)->name();
 //  else
-//      kDebug() << "loading" << url << "script" << autodetectScript;
+//      qDebug() << "loading" << url << "script" << autodetectScript;
 
 	FileLoadHelper fileLoadHelper(url);
 	if(!fileLoadHelper.open())
@@ -167,12 +166,13 @@ FormatManager::readSubtitle(Subtitle &subtitle, bool primary, const KUrl &url, K
 			const char *name = ucsdet_getName(ucms[index], &status);
 			qDebug() << "encoding" << name << "confidence" << confidence;
 			bool encodingFound;
-			*codec = KGlobal::charsets()->codecForName(name, encodingFound);
+			*codec = KCharsets::charsets()->codecForName(name, encodingFound);
 			if(encodingFound)
 				break;
 			else
 				*codec = 0;
 		}
+		ucsdet_close(csd);
 	}
 #endif
 	if(*codec) {
@@ -180,13 +180,11 @@ FormatManager::readSubtitle(Subtitle &subtitle, bool primary, const KUrl &url, K
 		textStream.setCodec(*codec);
 		stringData = textStream.readAll();
 	} else {
-		if(autodetectScript == KEncodingDetector::None)
-			autodetectScript = KEncodingDetector::SemiautomaticDetection;
-		// TODO is the value of KEncodingDetector::AutoDetectedEncoding correct??
-		KEncodingDetector detector(app()->generalConfig()->defaultSubtitlesCodec(), KEncodingDetector::AutoDetectedEncoding, autodetectScript);
-		stringData = detector.decode(byteData);
+		// FIXME: ?
+		KEncodingProber prober(KEncodingProber::Universal);
+		prober.feed(byteData);
 		bool encodingFound;
-		*codec = KGlobal::charsets()->codecForName(detector.encoding(), encodingFound);
+		*codec = KCharsets::charsets()->codecForName(prober.encoding(), encodingFound);
 	}
 
 	if(newLine) {
@@ -255,7 +253,7 @@ FormatManager::outputNames() const
 }
 
 bool
-FormatManager::writeSubtitle(const Subtitle &subtitle, bool primary, const KUrl &url, QTextCodec *codec, Format::NewLine newLine, const QString &formatName, bool overwrite) const
+FormatManager::writeSubtitle(const Subtitle &subtitle, bool primary, const QUrl &url, QTextCodec *codec, Format::NewLine newLine, const QString &formatName, bool overwrite) const
 {
 	const OutputFormat *format = output(formatName);
 	if(format == 0) {
