@@ -26,16 +26,14 @@
 
 #include "../inputformat.h"
 
-#include <QtCore/QRegExp>
+#include <QRegExp>
+#include <QStringBuilder>
 
 namespace SubtitleComposer {
 class MicroDVDInputFormat : public InputFormat
 {
 	friend class FormatManager;
 
-public:
-	virtual ~MicroDVDInputFormat() {}
-
 protected:
 	virtual bool parseSubtitles(Subtitle &subtitle, const QString &data) const
 	{
@@ -47,7 +45,7 @@ protected:
 		// if present, the FPS must by indicated by the first entry with both initial and final frames at 1
 		bool ok;
 		double framesPerSecond = m_lineRegExp.cap(3).toDouble(&ok);
-		if(ok && m_lineRegExp.cap(1) == "1" && m_lineRegExp.cap(2) == "1") {
+		if(ok && m_lineRegExp.cap(1) == QLatin1String("1") && m_lineRegExp.cap(2) == QLatin1String("1")) {
 			// first line contained the frames per second
 			subtitle.setFramesPerSecond(framesPerSecond);
 
@@ -80,7 +78,7 @@ protected:
 				int newStyle = currentStyle;
 				QRgb newColor = currentColor;
 
-				if(tag == "Y") {
+				if(tag == QLatin1String("Y")) {
 					globalStyle = 0;
 					if(val.contains('b'))
 						globalStyle |= SString::Bold;
@@ -88,9 +86,9 @@ protected:
 						globalStyle |= SString::Italic;
 					if(val.contains('u'))
 						globalStyle |= SString::Underline;
-				} else if(tag == "C") {
-					globalColor = val.length() != 7 ? 0 : QColor("#" + val.mid(5, 2) + val.mid(3, 2) + val.mid(1, 2)).rgb();
-				} else if(tag == "y") {
+				} else if(tag == QLatin1String("C")) {
+					globalColor = val.length() != 7 ? 0 : QColor(QChar('#') % val.mid(5, 2) % val.mid(3, 2) % val.mid(1, 2)).rgb();
+				} else if(tag == QLatin1String("y")) {
 					newStyle = 0;
 					if(val.contains('b'))
 						newStyle |= SString::Bold;
@@ -98,8 +96,8 @@ protected:
 						newStyle |= SString::Italic;
 					if(val.contains('u'))
 						newStyle |= SString::Underline;
-				} else if(tag == "c") {
-					newColor = val.length() != 7 ? 0 : QColor("#" + val.mid(5, 2) + val.mid(3, 2) + val.mid(1, 2)).rgb();
+				} else if(tag == QLatin1String("c")) {
+					newColor = val.length() != 7 ? 0 : QColor(QChar('#') % val.mid(5, 2) % val.mid(3, 2) % val.mid(1, 2)).rgb();
 				}
 
 				if(newStyle != currentStyle || currentColor != newColor) {
@@ -135,7 +133,7 @@ protected:
 	}
 
 	MicroDVDInputFormat() :
-		InputFormat("MicroDVD", QString("sub:txt").split(":")),
+		InputFormat(QStringLiteral("MicroDVD"), QStringList() << QStringLiteral("sub") << QStringLiteral("txt")),
 		m_lineRegExp("\\{(\\d+)\\}\\{(\\d+)\\}([^\n]+)\n", Qt::CaseInsensitive),
 		m_styleRegExp("\\{([yc]):([^}]*)\\}", Qt::CaseInsensitive)
 	{}
