@@ -26,7 +26,7 @@
 
 #include "../inputformat.h"
 
-#include <QtCore/QRegExp>
+#include <QRegExp>
 
 namespace SubtitleComposer {
 // FIXME TMPlayer Multiline variant
@@ -35,9 +35,6 @@ class TMPlayerInputFormat : public InputFormat
 {
 	friend class FormatManager;
 
-public:
-	virtual ~TMPlayerInputFormat() {}
-
 protected:
 	virtual bool parseSubtitles(Subtitle &subtitle, const QString &data) const
 	{
@@ -75,8 +72,8 @@ protected:
 	}
 
 	TMPlayerInputFormat() :
-		InputFormat("TMPlayer", QString("sub:txt").split(":")),
-		m_regExp("([0-2]?[0-9]):([0-5][0-9]):([0-5][0-9]):([^\n]*)\n?") {}
+		InputFormat(QStringLiteral("TMPlayer"), QStringList() << QStringLiteral("sub") << QStringLiteral("txt")),
+		m_regExp(QStringLiteral("([0-2]?[0-9]):([0-5][0-9]):([0-5][0-9]):([^\n]*)\n?")) {}
 
 	TMPlayerInputFormat(const QString &name, const QStringList &extensions, const QString &regExp) :
 		InputFormat(name, extensions),
@@ -91,7 +88,7 @@ class TMPlayerPlusInputFormat : public TMPlayerInputFormat
 
 protected:
 	TMPlayerPlusInputFormat() :
-		TMPlayerInputFormat("TMPlayer+", QString("sub:txt").split(":"), "([0-2]?[0-9]):([0-5][0-9]):([0-5][0-9])=([^\n]*)\n?")
+		TMPlayerInputFormat(QStringLiteral("TMPlayer+"), QStringList() << QStringLiteral("sub") << QStringLiteral("txt"), QStringLiteral("([0-2]?[0-9]):([0-5][0-9]):([0-5][0-9])=([^\n]*)\n?"))
 	{}
 };
 }
