@@ -32,9 +32,6 @@ class TMPlayerOutputFormat : public OutputFormat
 {
 	friend class FormatManager;
 
-public:
-	virtual ~TMPlayerOutputFormat() {}
-
 protected:
 	virtual QString dumpSubtitles(const Subtitle &subtitle, bool primary) const
 	{
@@ -64,7 +61,7 @@ protected:
 	}
 
 	TMPlayerOutputFormat() :
-		OutputFormat("TMPlayer", QString("sub:txt").split(":")),
+		OutputFormat(QStringLiteral("TMPlayer"), QStringList() << QStringLiteral("sub") << QStringLiteral("txt")),
 		m_timeFormat("%02d:%02d:%02d:")
 	{}
 
@@ -82,7 +79,7 @@ class TMPlayerPlusOutputFormat : public TMPlayerOutputFormat
 
 protected:
 	TMPlayerPlusOutputFormat() :
-		TMPlayerOutputFormat("TMPlayer+", QString("sub:txt").split(":"), "%02d:%02d:%02d=")
+		TMPlayerOutputFormat(QStringLiteral("TMPlayer+"), QStringList() << QStringLiteral("sub") << QStringLiteral("txt"), "%02d:%02d:%02d=")
 	{}
 };
 }
