@@ -19,8 +19,7 @@
 
 #include "useraction.h"
 #include "../../core/subtitle.h"
-#include "../../services/player.h"
-#include "../../services/decoder.h"
+#include "../../videoplayer/videoplayer.h"
 #include "../lineswidget.h"
 #include "../currentlinewidget.h"
 
@@ -43,7 +42,7 @@ UserAction::onActionChanged()
 {
 	if(!m_ignoreActionEnabledSignal) {
 		if(m_action->isEnabled() != isEnabled()) {
-			// kDebug() << "enabled state externaly changed for" << m_action->objectName();
+			// qDebug() << "enabled state externaly changed for" << m_action->objectName();
 
 			m_actionEnabled = m_action->isEnabled();
 			updateEnabledState();
@@ -100,7 +99,7 @@ UserAction::updateEnabledState()
 
 		// QCoreApplication::processEvents( QEventLoop::ExcludeUserInputEvents );
 
-		// kDebug() << "setting action" << (m_action->isEnabled() ? "ENABLED":"DISABLED");
+		// qDebug() << "setting action" << (m_action->isEnabled() ? "ENABLED":"DISABLED");
 
 		m_ignoreActionEnabledSignal = false;
 	}
@@ -114,7 +113,7 @@ UserActionManager::UserActionManager() :
 	m_linesWidget(0),
 	m_player(0),
 	m_translationMode(false),
-	m_contextFlags(UserAction::SubClosed | UserAction::SubTrClosed | UserAction::VideoClosed | UserAction::AudioLevelsClosed | UserAction::FullScreenOff)
+	m_contextFlags(UserAction::SubClosed | UserAction::SubTrClosed | UserAction::VideoClosed | UserAction::FullScreenOff | UserAction::AnchorsNone)
 {}
 
 UserActionManager *
@@ -128,7 +127,9 @@ UserActionManager::instance()
 void
 UserActionManager::addAction(QAction *action, int enableFlags)
 {
-	addAction(new UserAction(action, enableFlags));
+	UserAction *a = new UserAction(action, enableFlags);
+	addAction(a);
+	a->setParent(this); // UserActionManager will delete *a
 }
 
 void
@@ -149,6 +150,8 @@ UserActionManager::setSubtitle(Subtitle *subtitle)
 		disconnect(m_subtitle, SIGNAL(primaryDirtyStateChanged(bool)), this, SLOT(onPrimaryDirtyStateChanged(bool)));
 		disconnect(m_subtitle, SIGNAL(secondaryDirtyStateChanged(bool)), this, SLOT(onSecondaryDirtyStateChanged(bool)));
 
+		disconnect(m_subtitle, SIGNAL(lineAnchorChanged(const SubtitleLine*,bool)), this, SLOT(onSubtitleAnchorsChanged()));
+
 		disconnect(&(m_subtitle->actionManager()), SIGNAL(stateChanged()), this, SLOT(onUndoRedoStateChanged()));
 	}
 
@@ -165,6 +168,8 @@ UserActionManager::setSubtitle(Subtitle *subtitle)
 		connect(m_subtitle, SIGNAL(primaryDirtyStateChanged(bool)), this, SLOT(onPrimaryDirtyStateChanged(bool)));
 		connect(m_subtitle, SIGNAL(secondaryDirtyStateChanged(bool)), this, SLOT(onSecondaryDirtyStateChanged(bool)));
 
+		connect(m_subtitle, SIGNAL(lineAnchorChanged(const SubtitleLine*,bool)), this, SLOT(onSubtitleAnchorsChanged()));
+
 		connect(actionManager, SIGNAL(stateChanged()), this, SLOT(onUndoRedoStateChanged()));
 
 		newContextFlags |= UserAction::SubOpened;
@@ -190,6 +195,17 @@ UserActionManager::setSubtitle(Subtitle *subtitle)
 		if(m_subtitle->linesCount() > 1)
 			newContextFlags |= UserAction::SubHasLines;
 
+		const QList<const SubtitleLine *> &anchors = m_subtitle->anchoredLines();
+		if(anchors.empty()) {
+			newContextFlags |= UserAction::AnchorsNone;
+			newContextFlags |= UserAction::EditableShowTime;
+		} else {
+			newContextFlags |= UserAction::AnchorsSome;
+			const SubtitleLine *selected = m_subtitle->line(m_linesWidget->firstSelectedIndex());
+			if(anchors.indexOf(selected) != -1)
+				newContextFlags |= UserAction::EditableShowTime;
+		}
+
 		if(actionManager->hasUndo())
 			newContextFlags |= UserAction::SubHasUndo;
 		if(actionManager->hasRedo())
@@ -265,44 +281,38 @@ UserActionManager::setLinesWidget(LinesWidget *linesWidget)
 
 	m_linesWidget = linesWidget;
 
-	int newContextFlags = m_contextFlags & ~UserAction::SelectionMask;
-
 	if(m_linesWidget) {
 		connect(m_linesWidget->selectionModel(), SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)), this, SLOT(onLinesWidgetSelectionChanged()));
+		onLinesWidgetSelectionChanged();
+	}
+}
 
-		if(m_linesWidget->firstSelectedIndex() >= 0)
-			newContextFlags |= UserAction::HasSelection;
+void
+UserActionManager::onLinesWidgetSelectionChanged()
+{
+	int newContextFlags = m_contextFlags & ~(UserAction::SelectionMask | UserAction::EditableShowTime);
+
+	int selectedIndex = m_linesWidget->firstSelectedIndex();
+
+	if(selectedIndex >= 0)
+		newContextFlags |= UserAction::HasSelection;
+
+	if(m_subtitle) {
+		const QList<const SubtitleLine *> &anchors = m_subtitle->anchoredLines();
+		if(anchors.empty()) {
+			newContextFlags |= UserAction::EditableShowTime;
+		} else {
+			const SubtitleLine *line = m_subtitle->line(selectedIndex);
+			if(anchors.indexOf(line) != -1)
+				newContextFlags |= UserAction::EditableShowTime;
+		}
 	}
 
 	updateActionsContext(newContextFlags);
 }
 
 void
-UserActionManager::onLinesWidgetSelectionChanged()
-{
-	int newContextFlags = m_contextFlags & ~UserAction::SelectionMask;
-
-	if(m_linesWidget->firstSelectedIndex() >= 0)
-		newContextFlags |= UserAction::HasSelection;
-
-	updateActionsContext(newContextFlags);
-}
-
-void
-UserActionManager::setAudioLevels(AudioLevels *audiolevels)
-{
-	int newContextFlags = m_contextFlags & ~UserAction::AudioLevelsMask;
-
-	if(audiolevels)
-		newContextFlags |= UserAction::AudioLevelsOpened;
-	else
-		newContextFlags |= UserAction::AudioLevelsClosed;
-
-	updateActionsContext(newContextFlags);
-}
-
-void
-UserActionManager::setPlayer(Player *player)
+UserActionManager::setPlayer(VideoPlayer *player)
 {
 	if(m_player) {
 		disconnect(m_player, SIGNAL(fileOpened(const QString &)), this, SLOT(onPlayerStateChanged()));
@@ -324,9 +334,9 @@ UserActionManager::setPlayer(Player *player)
 		connect(m_player, SIGNAL(stopped()), this, SLOT(onPlayerStateChanged()));
 
 		int state = m_player->state();
-		if(state > Player::Opening) {
+		if(state > VideoPlayer::Opening) {
 			newContextFlags |= UserAction::VideoOpened;
-			if(state > Player::Paused)
+			if(state > VideoPlayer::Paused)
 				newContextFlags |= UserAction::VideoStopped;
 			else
 				newContextFlags |= UserAction::VideoPlaying;
@@ -344,9 +354,9 @@ UserActionManager::onPlayerStateChanged()
 	int newContextFlags = m_contextFlags & ~UserAction::VideoMask;
 
 	int state = m_player->state();
-	if(state > Player::Opening) {
+	if(state > VideoPlayer::Opening) {
 		newContextFlags |= UserAction::VideoOpened;
-		if(state > Player::Paused)
+		if(state > VideoPlayer::Paused)
 			newContextFlags |= UserAction::VideoStopped;
 		else
 			newContextFlags |= UserAction::VideoPlaying;
@@ -358,53 +368,19 @@ UserActionManager::onPlayerStateChanged()
 }
 
 void
-UserActionManager::setDecoder(Decoder *decoder)
+UserActionManager::onSubtitleAnchorsChanged()
 {
-	if(m_decoder) {
-		disconnect(m_decoder, SIGNAL(fileOpened(const QString &)), this, SLOT(onDecoderStateChanged()));
-		disconnect(m_decoder, SIGNAL(fileClosed()), this, SLOT(onDecoderStateChanged()));
-		disconnect(m_decoder, SIGNAL(decoding()), this, SLOT(onDecoderStateChanged()));
-		disconnect(m_decoder, SIGNAL(stopped()), this, SLOT(onDecoderStateChanged()));
-	}
+	int newContextFlags = m_contextFlags & ~UserAction::AnchorsMask;
 
-	m_decoder = decoder;
-
-	int newContextFlags = m_contextFlags & ~UserAction::AudioMask;
-
-	if(m_decoder) {
-		connect(m_decoder, SIGNAL(fileOpened(const QString &)), this, SLOT(onDecoderStateChanged()));
-		connect(m_decoder, SIGNAL(fileClosed()), this, SLOT(onDecoderStateChanged()));
-		connect(m_decoder, SIGNAL(decoding()), this, SLOT(onDecoderStateChanged()));
-		connect(m_decoder, SIGNAL(stopped()), this, SLOT(onDecoderStateChanged()));
-
-		int state = m_decoder->state();
-		if(state > Decoder::Opening) {
-			newContextFlags |= UserAction::AudioOpened;
-			if(state == Decoder::Decoding)
-				newContextFlags |= UserAction::AudioDecoding;
-			else
-				newContextFlags |= UserAction::AudioStopped;
-		} else
-			newContextFlags |= UserAction::AudioClosed;
-	}
-
-	updateActionsContext(newContextFlags);
-}
-
-void
-UserActionManager::onDecoderStateChanged()
-{
-	int newContextFlags = m_contextFlags & ~UserAction::AudioMask;
-
-	int state = m_decoder->state();
-	if(state > Decoder::Opening) {
-		newContextFlags |= UserAction::AudioOpened;
-		if(state == Decoder::Decoding)
-			newContextFlags |= UserAction::AudioDecoding;
-		else
-			newContextFlags |= UserAction::AudioStopped;
+	const QList<const SubtitleLine *> &anchors = m_subtitle->anchoredLines();
+	if(anchors.empty()) {
+		newContextFlags |= UserAction::AnchorsNone;
+		newContextFlags |= UserAction::EditableShowTime;
 	} else {
-		newContextFlags |= UserAction::AudioClosed;
+		newContextFlags |= UserAction::AnchorsSome;
+		const SubtitleLine *selected = m_subtitle->line(m_linesWidget->firstSelectedIndex());
+		if(anchors.indexOf(selected) != -1)
+			newContextFlags |= UserAction::EditableShowTime;
 	}
 
 	updateActionsContext(newContextFlags);
@@ -448,11 +424,11 @@ void
 UserActionManager::updateActionsContext(int contextFlags)
 {
 //  if ( (m_contextFlags & UserAction::SubHasLine) != (contextFlags & UserAction::SubHasLine)  )
-//      kDebug() << "has line:" << ((contextFlags & UserAction::SubHasLine) != 0);
+//      qDebug() << "has line:" << ((contextFlags & UserAction::SubHasLine) != 0);
 //  if ( (m_contextFlags & UserAction::SubHasLines) != (contextFlags & UserAction::SubHasLines)  )
-//      kDebug() << "has lines:" << ((contextFlags & UserAction::SubHasLines) != 0);
+//      qDebug() << "has lines:" << ((contextFlags & UserAction::SubHasLines) != 0);
 //  if ( (m_contextFlags & UserAction::HasSelection) != (contextFlags & UserAction::HasSelection)  )
-//      kDebug() << "has selection:" << ((contextFlags & UserAction::HasSelection) != 0);
+//      qDebug() << "has selection:" << ((contextFlags & UserAction::HasSelection) != 0);
 
 	if(m_contextFlags != contextFlags) {
 		m_contextFlags = contextFlags;
@@ -461,4 +437,4 @@ UserActionManager::updateActionsContext(int contextFlags)
 	}
 }
 
-#include "useraction.moc"
+
