@@ -24,13 +24,12 @@
 #include <config.h>
 #endif
 
-#include <QtCore/QList>
+#include <QList>
 
-#include <KAction>
+#include <QAction>
 
 namespace SubtitleComposer {
 class Subtitle;
-class AudioLevels;
 class LinesWidget;
 class CurrentLineWidget;
 
@@ -40,39 +39,35 @@ class UserAction : public QObject
 
 public:
 	typedef enum {
-		SubClosed = 0x1,                // Subtitle is not opened
-		SubOpened = 0x2,                // Subtitle is opened
-		SubTrClosed = 0x4,              // Subtitle is not opened
-		SubTrOpened = 0x8,              // Subtitle is opened
-		SubHasLine = 0x10,              // Subtitle opened with, at least, one line
-		SubHasLines = 0x20,             // Subtitle opened with, at least, two lines
-		SubPDirty = 0x40,               // Subtitle opened and has unsaved changes
-		SubPClean = 0x80,               // Subtitle opened or closed without unsaved changes
-		SubSDirty = 0x100,              // Subtitle opened and has unsaved changes
-		SubSClean = 0x200,              // Subtitle opened or closed without unsaved changes
-		SubHasUndo = 0x400,             // An action can be undone
-		SubHasRedo = 0x800,             // An action can be redone
-		HasSelection = 0x1000,          // Subtitle opened with, at least, one line selected
-		VideoClosed = 0x2000,
-		VideoOpened = 0x4000,
-		VideoStopped = 0x8000,
-		VideoPlaying = 0x10000,
-		AudioClosed = 0x20000,
-		AudioOpened = 0x40000,
-		AudioStopped = 0x80000,
-		AudioDecoding = 0x100000,
-		AudioLevelsClosed = 0x200000,
-		AudioLevelsOpened = 0x400000,
-		FullScreenOn = 0x800000,
-		FullScreenOff = 0x1000000,
+		SubClosed        = 0x1,	// Subtitle is not opened
+		SubOpened        = 0x2,	// Subtitle is opened
+		SubTrClosed      = 0x4,	// Subtitle is not opened
+		SubTrOpened      = 0x8,	// Subtitle is opened
+		SubHasLine       = 0x10,	// Subtitle opened with, at least, one line
+		SubHasLines      = 0x20,	// Subtitle opened with, at least, two lines
+		SubPDirty        = 0x40,	// Subtitle opened and has unsaved changes
+		SubPClean        = 0x80,	// Subtitle opened or closed without unsaved changes
+		SubSDirty        = 0x100,	// Subtitle opened and has unsaved changes
+		SubSClean        = 0x200,	// Subtitle opened or closed without unsaved changes
+		SubHasUndo       = 0x400,	// An action can be undone
+		SubHasRedo       = 0x800,	// An action can be redone
+		HasSelection     = 0x1000,	// Subtitle opened with, at least, one line selected
+		VideoClosed      = 0x2000,
+		VideoOpened      = 0x4000,
+		VideoStopped     = 0x8000,
+		VideoPlaying     = 0x10000,
+		FullScreenOn     = 0x20000,
+		FullScreenOff    = 0x40000,
+		AnchorsNone      = 0x80000,	// None of the subtitles is anchored
+		AnchorsSome      = 0x100000,	// At least one subtitle is anchored
+		EditableShowTime = 0x200000,	// Selected line's show time is editable
 
-		SubtitleMask = SubClosed | SubOpened | SubTrClosed | SubTrOpened | SubPDirty | SubPClean | SubSDirty | SubSClean | SubHasLine | SubHasLines | SubHasUndo | SubHasRedo,
+		AnchorsMask = AnchorsNone | AnchorsSome | EditableShowTime,
+		SubtitleMask = SubClosed | SubOpened | SubTrClosed | SubTrOpened | SubPDirty | SubPClean | SubSDirty | SubSClean | SubHasLine | SubHasLines | SubHasUndo | SubHasRedo | AnchorsMask,
 		SelectionMask = HasSelection,
 		VideoMask = VideoClosed | VideoOpened | VideoStopped | VideoPlaying,
-		AudioMask = AudioClosed | AudioOpened | AudioStopped | AudioDecoding,
-		AudioLevelsMask = AudioLevelsClosed | AudioLevelsOpened,
 		FullScreenMask = FullScreenOn | FullScreenOff,
-		AllMask = SubtitleMask | SelectionMask | VideoMask | AudioLevelsMask | FullScreenMask
+		AllMask = AnchorsMask | SubtitleMask | SelectionMask | VideoMask | FullScreenMask
 	} EnableFlag;
 
 	explicit UserAction(QAction *action, int enableFlags = SubOpened);
@@ -100,8 +95,7 @@ private:
 	bool m_ignoreActionEnabledSignal;
 };
 
-class Player;
-class Decoder;
+class VideoPlayer;
 
 class UserActionManager : public QObject
 {
@@ -117,9 +111,7 @@ public:
 public slots:
 	void setSubtitle(Subtitle *subtitle = 0);
 	void setLinesWidget(LinesWidget *linesWidget = 0);
-	void setAudioLevels(AudioLevels *audiolevels = 0);
-	void setPlayer(Player *player = 0);
-	void setDecoder(Decoder *decoder = 0);
+	void setPlayer(VideoPlayer *player = 0);
 	void setTranslationMode(bool translationMode);
 	void setFullScreenMode(bool fullScreenMode);
 
@@ -135,15 +127,14 @@ private slots:
 	void onUndoRedoStateChanged();
 	void onLinesWidgetSelectionChanged();
 	void onPlayerStateChanged();
-	void onDecoderStateChanged();
+	void onSubtitleAnchorsChanged();
 
 private:
 	QList<UserAction *> m_actionSpecs;
 
 	const Subtitle *m_subtitle;
 	const LinesWidget *m_linesWidget;
-	const Player *m_player;
-	const Decoder *m_decoder;
+	const VideoPlayer *m_player;
 	bool m_translationMode;
 
 	int m_contextFlags;
