@@ -1,40 +1,40 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "currentlinewidget.h"
 #include "application.h"
-#include "configs/spellingconfig.h"
 #include "actions/useractionnames.h"
 #include "../widgets/timeedit.h"
 #include "../widgets/simplerichtextedit.h"
 
-#include <QtCore/QTimer>
-#include <QtGui/QLabel>
-#include <QtGui/QToolButton>
-#include <QtGui/QGroupBox>
-#include <QtGui/QGridLayout>
-#include <QtGui/QKeyEvent>
+#include <QTimer>
+#include <QLabel>
+#include <QToolButton>
+#include <QGroupBox>
+#include <QGridLayout>
+#include <QKeyEvent>
+#include <QDebug>
+#include <QIcon>
 
-#include <KDebug>
-#include <KLocale>
-#include <KIcon>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
@@ -43,7 +43,7 @@ CurrentLineWidget::createToolButton(const QString &text, const char *icon, QObje
 {
 	QToolButton *toolButton = new QToolButton(this);
 	toolButton->setToolTip(text);
-	toolButton->setIcon(KIcon(icon));
+	toolButton->setIcon(QIcon::fromTheme(icon));
 	toolButton->setMinimumSize(20, 20);
 	toolButton->setMaximumSize(20, 20);
 	toolButton->setCheckable(checkable);
@@ -55,7 +55,8 @@ CurrentLineWidget::createToolButton(const QString &text, const char *icon, QObje
 
 CurrentLineWidget::CurrentLineWidget(QWidget *parent) :
 	QWidget(parent),
-	m_currentLine(0),
+	m_subtitle(NULL),
+	m_currentLine(NULL),
 	m_translationMode(false),
 	m_updateCurrentLine(true),
 	m_updateControls(true),
@@ -160,7 +161,7 @@ CurrentLineWidget::CurrentLineWidget(QWidget *parent) :
 
 	connect(m_updateShorcutsTimer, SIGNAL(timeout()), this, SLOT(updateShortcuts()));
 
-	connect(app()->spellingConfig(), SIGNAL(optionChanged(const QString &, const QString &)), this, SLOT(onSpellingOptionChanged(const QString &, const QString &)));
+	connect(SCConfig::self(), SIGNAL(configChanged()), this, SLOT(onConfigChanged()));
 }
 
 CurrentLineWidget::~CurrentLineWidget()
@@ -178,7 +179,7 @@ CurrentLineWidget::focusedText() const
 void
 CurrentLineWidget::loadConfig()
 {
-	KConfigGroup group(KGlobal::config()->group("Current Line Settings"));
+	KConfigGroup group(KSharedConfig::openConfig()->group("Current Line Settings"));
 
 	m_textEdits[0]->setCheckSpellingEnabled(group.readEntry<bool>("PrimaryCheckSpelling", false));
 	m_textEdits[1]->setCheckSpellingEnabled(group.readEntry<bool>("TranslationCheckSpelling", false));
@@ -187,7 +188,7 @@ CurrentLineWidget::loadConfig()
 void
 CurrentLineWidget::saveConfig()
 {
-	KConfigGroup group(KGlobal::config()->group("Current Line Settings"));
+	KConfigGroup group(KSharedConfig::openConfig()->group("Current Line Settings"));
 
 	group.writeEntry("PrimaryCheckSpelling", m_textEdits[0]->checkSpellingEnabled());
 	group.writeEntry("TranslationCheckSpelling", m_textEdits[1]->checkSpellingEnabled());
@@ -196,8 +197,15 @@ CurrentLineWidget::saveConfig()
 void
 CurrentLineWidget::setSubtitle(Subtitle *subtitle)
 {
-	if(!subtitle)
-		setCurrentLine(0);
+	if(m_subtitle)
+		disconnect(m_subtitle, SIGNAL(lineAnchorChanged(const SubtitleLine*,bool)), this, SLOT(onLineAnchorChanged(const SubtitleLine*,bool)));
+
+	m_subtitle = subtitle;
+
+	if(subtitle)
+		connect(m_subtitle, SIGNAL(lineAnchorChanged(const SubtitleLine*,bool)), this, SLOT(onLineAnchorChanged(const SubtitleLine*,bool)));
+	else
+		setCurrentLine(NULL);
 }
 
 void
@@ -225,6 +233,8 @@ CurrentLineWidget::setCurrentLine(SubtitleLine *line)
 	if(m_currentLine) {
 		onLinePrimaryTextChanged(m_currentLine->primaryText());
 		onLineSecondaryTextChanged(m_currentLine->secondaryText());
+		if(m_subtitle)
+			onLineAnchorChanged(m_currentLine, m_subtitle->isLineAnchored(m_currentLine));
 	} else {
 		m_updateCurrentLine = false;
 
@@ -330,6 +340,7 @@ CurrentLineWidget::onShowTimeEditChanged(int showTime)
 	if(m_updateCurrentLine) {
 		m_updateControls = false;
 		m_currentLine->setShowTime(showTime);
+		m_hideTimeEdit->setValue(m_currentLine->hideTime().toMillis());
 		m_durationTimeEdit->setValue(m_hideTimeEdit->value() - showTime);
 		m_updateControls = true;
 	}
@@ -385,6 +396,13 @@ CurrentLineWidget::buildTextDescription(const QString &text)
 	return currentLineText + expressionText + i18np("1 character", "%1 characters", characters);
 }
 
+void
+CurrentLineWidget::onLineAnchorChanged(const SubtitleLine *line, bool anchored)
+{
+	if(m_subtitle && line == m_currentLine)
+		m_showTimeEdit->setEnabled(m_subtitle->anchoredLines().empty() || anchored);
+}
+
 void
 CurrentLineWidget::onLinePrimaryTextChanged(const SString &primaryText)
 {
@@ -456,7 +474,7 @@ void
 CurrentLineWidget::setupActions()
 {
 	for(int index = 0; index < 2; ++index) {
-		KAction *spellingAction = m_textEdits[index]->action(SimpleRichTextEdit::CheckSpelling);
+		QAction *spellingAction = m_textEdits[index]->action(SimpleRichTextEdit::CheckSpelling);
 		spellingAction->disconnect();
 		connect(spellingAction, SIGNAL(triggered()), app(), SLOT(spellCheck()));
 	}
@@ -481,19 +499,19 @@ CurrentLineWidget::markUpdateShortcuts()
 static void
 mapShortcuts(SimpleRichTextEdit *textEdit, int textEditActionID, const char *appActionID)
 {
-	KAction *textEditAction = textEdit->action(textEditActionID);
-	KAction *appAction = static_cast<KAction *>(app()->action(appActionID));
+	QAction *textEditAction = textEdit->action(textEditActionID);
+	QAction *appAction = static_cast<QAction *>(app()->action(appActionID));
 	if(textEditAction && appAction)
 		textEditAction->setShortcut(appAction->shortcut());
 }
 
 void
-CurrentLineWidget::onSpellingOptionChanged(const QString &option, const QString &value)
+CurrentLineWidget::onConfigChanged()
 {
-	if(option == SpellingConfig::keyDefaultLanguage()) {
-		m_textEdits[0]->setSpellCheckingLanguage(value);
-		m_textEdits[1]->setSpellCheckingLanguage(value);
-	}
+//	if(option == SpellingConfig::keyDefaultLanguage()) {
+		m_textEdits[0]->setSpellCheckingLanguage(SCConfig::defaultLanguage());
+		m_textEdits[1]->setSpellCheckingLanguage(SCConfig::defaultLanguage());
+//	}
 }
 
 #include <KStandardShortcut>
@@ -549,9 +567,9 @@ CurrentLineWidget::eventFilter(QObject *object, QEvent *event)
 
 			QKeySequence keySequence((keyEvent->modifiers() & ~Qt::KeypadModifier) + keyEvent->key());
 
-			KAction *action;
+			QAction *action;
 			foreach(action, m_textEdits[0]->actions()) {
-				if(action->shortcut().primary() == keySequence || action->shortcut().alternate() == keySequence)
+				if(action->shortcut().matches(keySequence) == QKeySequence::ExactMatch)
 					return QWidget::eventFilter(object, event);
 			}
 
@@ -562,4 +580,4 @@ CurrentLineWidget::eventFilter(QObject *object, QEvent *event)
 	return QWidget::eventFilter(object, event);
 }
 
-#include "currentlinewidget.moc"
+
