@@ -1,24 +1,25 @@
 #ifndef CURRENTLINEWIDGET_H
 #define CURRENTLINEWIDGET_H
 
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -27,12 +28,12 @@
 #include "../core/subtitle.h"
 #include "../core/subtitleline.h"
 
-#include <QtGui/QWidget>
+#include <QWidget>
 
-class QTimer;
-class QGridLayout;
-class QLabel;
-class QToolButton;
+QT_FORWARD_DECLARE_CLASS(QTimer)
+QT_FORWARD_DECLARE_CLASS(QGridLayout)
+QT_FORWARD_DECLARE_CLASS(QLabel)
+QT_FORWARD_DECLARE_CLASS(QToolButton)
 class TimeEdit;
 class SimpleRichTextEdit;
 
@@ -55,7 +56,7 @@ public:
 	virtual bool eventFilter(QObject *object, QEvent *event);
 
 public slots:
-	void setSubtitle(Subtitle *subtitle = 0);
+	void setSubtitle(Subtitle *subtitle = NULL);
 	void setCurrentLine(SubtitleLine *line);
 
 	void setTranslationMode(bool enabled);
@@ -73,12 +74,14 @@ protected slots:
 	void onHideTimeEditChanged(int hideTime);
 	void onDurationTimeEditChanged(int durationTime);
 
+	void onLineAnchorChanged(const SubtitleLine *line, bool anchored);
+
 	void onLinePrimaryTextChanged(const SString &primaryText);
 	void onLineSecondaryTextChanged(const SString &secondaryText);
 	void onLineShowTimeChanged(const Time &showTime);
 	void onLineHideTimeChanged(const Time &hideTime);
 
-	void onSpellingOptionChanged(const QString &option, const QString &value);
+	void onConfigChanged();
 
 	void markUpdateShortcuts();
 	void updateShortcuts();
@@ -89,6 +92,7 @@ private:
 	QString buildTextDescription(const QString &text);
 
 protected:
+	Subtitle *m_subtitle;
 	SubtitleLine *m_currentLine;
 	bool m_translationMode;
 
