@@ -26,15 +26,15 @@
 
 #include "actionwitherrortargetsdialog.h"
 
-class QCheckBox;
+QT_FORWARD_DECLARE_CLASS(QCheckBox)
 
 namespace SubtitleComposer {
-class CheckErrorsDialog : public ActionWithErrorTargetsDialog
+class ChecqCriticalsDialog : public ActionWithErrorTargetsDialog
 {
 	Q_OBJECT
 
 public:
-	CheckErrorsDialog(QWidget *parent = 0);
+	ChecqCriticalsDialog(QWidget *parent = 0);
 
 	bool clearOtherErrors() const;
 	bool clearMarks() const;
