@@ -27,9 +27,9 @@
 #include "selectablesubtitledialog.h"
 #include "../../core/time.h"
 
-class QCheckBox;
+QT_FORWARD_DECLARE_CLASS(QCheckBox)
+QT_FORWARD_DECLARE_CLASS(QPushButton)
 class TimeEdit;
-class KPushButton;
 
 namespace SubtitleComposer {
 class JoinSubtitlesDialog : public SelectableSubtitleDialog
@@ -48,7 +48,7 @@ private slots:
 
 private:
 	TimeEdit *m_shiftTimeEdit;
-	KPushButton *m_shiftTimeFromVideoButton;
+	QPushButton *m_shiftTimeFromVideoButton;
 	QCheckBox *m_shiftSubtitleCheckBox;
 };
 }
