@@ -1,41 +1,43 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "selectablesubtitledialog.h"
 #include "opensubtitledialog.h"
 #include "../application.h"
 
-#include <QtCore/QTextCodec>
-#include <QtGui/QLabel>
-#include <QtGui/QGroupBox>
-#include <QtGui/QGridLayout>
+#include <QTextCodec>
+#include <QLabel>
+#include <QGroupBox>
+#include <QGridLayout>
+#include <QPushButton>
+#include <QIcon>
 
-#include <KApplication>
-#include <KPushButton>
-#include <kurlcompletion.h>
+#include <KUrlCompletion>
 #include <KComboBox>
 #include <KLineEdit>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
-SelectableSubtitleDialog::SelectableSubtitleDialog(const QString &title, QWidget *parent) :
-	ActionWithTargetDialog(title, parent)
+SelectableSubtitleDialog::SelectableSubtitleDialog(const QString &title, QWidget *parent)
+	: ActionWithTargetDialog(title, parent)
 {}
 
 QGroupBox *
@@ -50,8 +52,8 @@ SelectableSubtitleDialog::createSubtitleGroupBox(const QString &title, bool addT
 	subtitlePathLabel->setText(i18n("Path:"));
 	subtitlePathLabel->setBuddy(m_subtitleUrlLineEdit);
 
-	KPushButton *subtitleButton = new KPushButton(m_subtitleGroupBox);
-	subtitleButton->setIcon(KIcon("document-open"));
+	QPushButton *subtitleButton = new QPushButton(m_subtitleGroupBox);
+	subtitleButton->setIcon(QIcon::fromTheme("document-open"));
 	subtitleButton->setToolTip(i18n("Select subtitle"));
 	int buttonSize = subtitleButton->sizeHint().height();
 	subtitleButton->setFixedSize(buttonSize, buttonSize);
@@ -88,10 +90,10 @@ SelectableSubtitleDialog::createSubtitleGroupBox(const QString &title, bool addT
 void
 SelectableSubtitleDialog::selectSubtitle()
 {
-	OpenSubtitleDialog openDlg(true, subtitleUrl().isEmpty() ? app()->lastSubtitleDirectory().prettyUrl() : subtitleUrl().prettyUrl(), subtitleEncoding());
+	OpenSubtitleDialog openDlg(true, subtitleUrl().isEmpty() ? app()->lastSubtitleDirectory() : subtitleUrl(), subtitleEncoding());
 
 	if(openDlg.exec() == QDialog::Accepted) {
-		m_subtitleUrlLineEdit->setText(openDlg.selectedFile());
+		m_subtitleUrlLineEdit->setText(openDlg.selectedUrl().toLocalFile());
 		if(openDlg.selectedEncoding().isEmpty())
 			m_subtitleEncodingComboBox->setCurrentItem(i18n("Autodetect"));
 		else
@@ -99,10 +101,10 @@ SelectableSubtitleDialog::selectSubtitle()
 	}
 }
 
-KUrl
+QUrl
 SelectableSubtitleDialog::subtitleUrl() const
 {
-	return KUrl(m_subtitleUrlLineEdit->text());
+	return QUrl(m_subtitleUrlLineEdit->text());
 }
 
 QString
@@ -114,4 +116,4 @@ SelectableSubtitleDialog::subtitleEncoding() const
 		return m_subtitleEncodingComboBox->currentText();
 }
 
-#include "selectablesubtitledialog.moc"
+
