@@ -27,9 +27,9 @@
 #include "actiondialog.h"
 #include "../../core/time.h"
 
-class QCheckBox;
+QT_FORWARD_DECLARE_CLASS(QCheckBox)
+QT_FORWARD_DECLARE_CLASS(QPushButton)
 class TimeEdit;
-class KPushButton;
 
 namespace SubtitleComposer {
 class SplitSubtitleDialog : public ActionDialog
@@ -49,7 +49,7 @@ private slots:
 
 private:
 	TimeEdit *m_splitTimeEdit;
-	KPushButton *m_splitTimeFromVideoButton;
+	QPushButton *m_splitTimeFromVideoButton;
 	QCheckBox *m_shiftNewSubtitleCheckBox;
 };
 }
