@@ -1,43 +1,44 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "profiler.h"
 
 #include "errorswidget.h"
 #include "application.h"
-#include "configs/errorsconfig.h"
 #include "../core/subtitle.h"
 #include "../core/subtitleline.h"
 
 #include <climits>
 
-#include <QtCore/QTimer>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QContextMenuEvent>
-#include <QtGui/QHeaderView>
+#include <QTimer>
+#include <QKeyEvent>
+#include <QMouseEvent>
+#include <QContextMenuEvent>
+#include <QHeaderView>
+#include <QIcon>
+#include <QMenu>
+#include <QDebug>
 
-#include <KMenu>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
@@ -407,7 +408,7 @@ ErrorsModel::index(int row, int column, const QModelIndex &parent) const
 		if(row < 0 || row >= m_lineWithErrorsCount)
 			return QModelIndex();
 
-//      kDebug() << "retrieved level 1 CHILD index " << row;
+//      qDebug() << "retrieved level 1 CHILD index " << row;
 
 		return createIndex(row, column, (void *)&LEVEL1_LINE);
 	}
@@ -415,11 +416,11 @@ ErrorsModel::index(int row, int column, const QModelIndex &parent) const
 		if(row >= rowCount(parent) || row < 0 /*|| column != Number */)
 			return QModelIndex();
 
-//      kDebug() << "retrieved level 2 CHILD index " << row;
+//      qDebug() << "retrieved level 2 CHILD index " << row;
 
 		return createIndex(row, column, m_subtitle->line(mapModelL1RowToLineIndex(parent.row())));
 	} else {                                        // if ( line ) // index is a second level item (error item)
-//      kDebug() << "attempted to retrieve level 3 CHILD index " << row;
+//      qDebug() << "attempted to retrieve level 3 CHILD index " << row;
 
 		return QModelIndex();
 	}
@@ -431,16 +432,16 @@ ErrorsModel::parent(const QModelIndex &index) const
 	SubtitleLine *line = static_cast<SubtitleLine *>(index.internalPointer());
 
 	if(!line) {                                     // index is a root level item
-//      kDebug() << "attempted to retrieve level -1 PARENT index" << -2;
+//      qDebug() << "attempted to retrieve level -1 PARENT index" << -2;
 
 		return QModelIndex();
 	}
 	if(line == &LEVEL1_LINE) {      // index is a first level item (line item)
-//      kDebug() << "retrieved level 0 PARENT index" << -1;
+//      qDebug() << "retrieved level 0 PARENT index" << -1;
 
 		return QModelIndex();
 	} else {                                        // if ( line ) // index is a second level item (error item)
-//      kDebug() << "retrieved level 1 PARENT index" << line->index();
+//      qDebug() << "retrieved level 1 PARENT index" << line->index();
 
 		return createIndex(mapLineIndexToModelL1Row(line->index()), 0, (void *)&LEVEL1_LINE);
 	}
@@ -511,7 +512,7 @@ ErrorsModel::markIcon()
 	static QIcon markIcon;
 
 	if(markIcon.isNull())
-		markIcon = KIcon("dialog-warning");
+		markIcon = QIcon::fromTheme("dialog-warning");
 
 	return markIcon;
 }
@@ -522,7 +523,7 @@ ErrorsModel::errorIcon()
 	static QIcon errorIcon;
 
 	if(errorIcon.isNull())
-		errorIcon = KIcon("dialog-error");
+		errorIcon = QIcon::fromTheme("dialog-error");
 
 	return errorIcon;
 }
@@ -537,9 +538,9 @@ ErrorsWidget::ErrorsWidget(QWidget *parent) :
 	setModel(new ErrorsModel(this));
 
 	QHeaderView *header = this->header();
-	header->setResizeMode(ErrorsModel::Number, QHeaderView::Interactive);
-	header->setResizeMode(ErrorsModel::ErrorCount, QHeaderView::Interactive);
-	header->setResizeMode(ErrorsModel::UserMark, QHeaderView::Interactive);
+	header->setSectionResizeMode(ErrorsModel::Number, QHeaderView::Interactive);
+	header->setSectionResizeMode(ErrorsModel::ErrorCount, QHeaderView::Interactive);
+	header->setSectionResizeMode(ErrorsModel::UserMark, QHeaderView::Interactive);
 
 	setSortingEnabled(false);
 	setRootIsDecorated(true);
@@ -567,10 +568,10 @@ ErrorsWidget::expandAll()
 void
 ErrorsWidget::loadConfig()
 {
-	KConfigGroup group(KGlobal::config()->group("ErrorsWidget Settings"));
+	KConfigGroup group(KSharedConfig::openConfig()->group("ErrorsWidget Settings"));
 
 	QByteArray state;
-	QStringList strState = group.readXdgListEntry("Columns State", QString("").split(' '));
+	QStringList strState = group.readXdgListEntry("Columns State", QStringList() << QString());
 	for(QStringList::ConstIterator it = strState.begin(), end = strState.end(); it != end; ++it)
 		state.append((char)(*it).toInt());
 	header()->restoreState(state);
@@ -579,7 +580,7 @@ ErrorsWidget::loadConfig()
 void
 ErrorsWidget::saveConfig()
 {
-	KConfigGroup group(KGlobal::config()->group("ErrorsWidget Settings"));
+	KConfigGroup group(KSharedConfig::openConfig()->group("ErrorsWidget Settings"));
 
 	QStringList strState;
 	QByteArray state = header()->saveState();
@@ -666,7 +667,7 @@ ErrorsWidget::contextMenuEvent(QContextMenuEvent *event)
 	errorCount -= markCount;
 
 	if(lineWithErrorsCount || errorCount || markCount) {
-		KMenu menu;
+		QMenu menu;
 		Application *app = Application::instance();
 
 		menu.addAction(i18n("Expand All"), this, SLOT(expandAll()));
@@ -677,7 +678,7 @@ ErrorsWidget::contextMenuEvent(QContextMenuEvent *event)
 		menu.addAction(i18n("Clear Selected Marks"), app, SLOT(clearSelectedMarks()))->setEnabled(markCount);
 		menu.addAction(i18n("Clear Selected Errors"), app, SLOT(clearSelectedErrors()))->setEnabled(errorCount);
 
-		if(!app->errorsConfig()->autoClearFixed()) {
+		if(!SCConfig::autoClearFixed()) {
 			menu.addSeparator();
 
 			menu.addAction(i18n("Clear Fixed Selection"), app, SLOT(recheckSelectedErrors()))->setEnabled(errorCount);
@@ -804,4 +805,4 @@ ErrorsWidget::keyPressEvent(QKeyEvent *event)
 		TreeView::keyPressEvent(event);
 }
 
-#include "errorswidget.moc"
+
