@@ -28,10 +28,10 @@
 #include "../core/subtitle.h"
 #include "../widgets/treeview.h"
 
-#include <QtCore/QList>
-#include <QtCore/QAbstractItemModel>
+#include <QList>
+#include <QAbstractItemModel>
 
-class QTimer;
+QT_FORWARD_DECLARE_CLASS(QTimer)
 
 namespace SubtitleComposer {
 class ErrorsModel;
