@@ -1,46 +1,46 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "lineswidget.h"
 #include "application.h"
-#include "configs/generalconfig.h"
 #include "dialogs/actionwithtargetdialog.h"
 #include "profiler.h"
 
-#include <QtCore/QVariant>
-#include <QtCore/QTimer>
-#include <QtCore/QEvent>
-#include <QtGui/QScrollBar>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QDropEvent>
-#include <QtGui/QPainter>
-#include <QtGui/QFontMetrics>
-#include <QtGui/QTextDocument>
-#include <QtGui/QAbstractTextDocumentLayout>
-#include <QtGui/QHeaderView>
+#include <QVariant>
+#include <QTimer>
+#include <QEvent>
+#include <QScrollBar>
+#include <QDropEvent>
+#include <QMimeData>
+#include <QPainter>
+#include <QFontMetrics>
+#include <QTextDocument>
+#include <QAbstractTextDocumentLayout>
+#include <QHeaderView>
 
-#include <KDebug>
-#include <KLocale>
+#include <QIcon>
+#include <QDebug>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KMenu>
-#include <KUrl>
+#include <QMenu>
+#include <QUrl>
 
 #if QT_VERSION >= 0x40500
 #define TEXT_DOCUMENT_CORRECTION 4
@@ -55,11 +55,12 @@ using namespace SubtitleComposer;
 
 LinesModel::LinesModel(QObject *parent) :
 	QAbstractListModel(parent),
-	m_subtitle(0),
-	m_playingLine(0),
+	m_subtitle(NULL),
+	m_playingLine(NULL),
 	m_dataChangedTimer(new QTimer(this)),
 	m_minChangedLineIndex(-1),
-	m_maxChangedLineIndex(-1)
+	m_maxChangedLineIndex(-1),
+	m_graftPoints(QList<Subtitle *>())
 {
 	m_dataChangedTimer->setInterval(0);
 	m_dataChangedTimer->setSingleShot(true);
@@ -80,21 +81,17 @@ LinesModel::setSubtitle(Subtitle *subtitle)
 		m_playingLine = 0;
 
 		if(m_subtitle) {
-/*			disconnect( m_subtitle, SIGNAL( linesAboutToBeInserted( int, int ) ),
-												this, SLOT( onLinesAboutToBeInserted( int, int ) ) );*/
 			disconnect(m_subtitle, SIGNAL(linesInserted(int, int)), this, SLOT(onLinesInserted(int, int)));
-/*			disconnect( m_subtitle, SIGNAL( linesAboutToBeRemoved( int, int ) ),
-												this, SLOT( onLinesAboutToBeRemoved( int, int ) ) );*/
 			disconnect(m_subtitle, SIGNAL(linesRemoved(int, int)), this, SLOT(onLinesRemoved(int, int)));
 
-			disconnect(m_subtitle, SIGNAL(lineErrorFlagsChanged(SubtitleLine *, int)), this, SLOT(onLineChanged(SubtitleLine *)));
-			disconnect(m_subtitle, SIGNAL(linePrimaryTextChanged(SubtitleLine *, const SString &)), this, SLOT(onLineChanged(SubtitleLine *)));
-			disconnect(m_subtitle, SIGNAL(lineSecondaryTextChanged(SubtitleLine *, const SString &)), this, SLOT(onLineChanged(SubtitleLine *)));
-			disconnect(m_subtitle, SIGNAL(lineShowTimeChanged(SubtitleLine *, const Time &)), this, SLOT(onLineChanged(SubtitleLine *)));
-			disconnect(m_subtitle, SIGNAL(lineHideTimeChanged(SubtitleLine *, const Time &)), this, SLOT(onLineChanged(SubtitleLine *)));
+			disconnect(m_subtitle, &Subtitle::lineAnchorChanged, this, &LinesModel::onLineChanged);
+			disconnect(m_subtitle, &Subtitle::lineErrorFlagsChanged, this, &LinesModel::onLineChanged);
+			disconnect(m_subtitle, &Subtitle::linePrimaryTextChanged, this, &LinesModel::onLineChanged);
+			disconnect(m_subtitle, &Subtitle::lineSecondaryTextChanged, this, &LinesModel::onLineChanged);
+			disconnect(m_subtitle, &Subtitle::lineShowTimeChanged, this, &LinesModel::onLineChanged);
+			disconnect(m_subtitle, &Subtitle::lineHideTimeChanged, this, &LinesModel::onLineChanged);
 
 			if(m_subtitle->linesCount()) {
-//              onLinesAboutToBeRemoved( 0, m_subtitle->linesCount() - 1 );
 				onLinesRemoved(0, m_subtitle->linesCount() - 1);
 			}
 		}
@@ -103,26 +100,28 @@ LinesModel::setSubtitle(Subtitle *subtitle)
 
 		if(m_subtitle) {
 			if(m_subtitle->linesCount()) {
-//              onLinesAboutToBeInserted( 0, m_subtitle->linesCount() - 1 );
 				onLinesInserted(0, m_subtitle->linesCount() - 1);
 			}
 
-/*			connect( m_subtitle, SIGNAL( linesAboutToBeInserted( int, int ) ),
-										this, SLOT( onLinesAboutToBeInserted( int, int ) ) );*/
 			connect(m_subtitle, SIGNAL(linesInserted(int, int)), this, SLOT(onLinesInserted(int, int)));
-/*			connect( m_subtitle, SIGNAL( linesAboutToBeRemoved( int, int ) ),
-										this, SLOT( onLinesAboutToBeRemoved( int, int ) ) );*/
 			connect(m_subtitle, SIGNAL(linesRemoved(int, int)), this, SLOT(onLinesRemoved(int, int)));
 
-			connect(m_subtitle, SIGNAL(lineErrorFlagsChanged(SubtitleLine *, int)), this, SLOT(onLineChanged(SubtitleLine *)));
-			connect(m_subtitle, SIGNAL(linePrimaryTextChanged(SubtitleLine *, const SString &)), this, SLOT(onLineChanged(SubtitleLine *)));
-			connect(m_subtitle, SIGNAL(lineSecondaryTextChanged(SubtitleLine *, const SString &)), this, SLOT(onLineChanged(SubtitleLine *)));
-			connect(m_subtitle, SIGNAL(lineShowTimeChanged(SubtitleLine *, const Time &)), this, SLOT(onLineChanged(SubtitleLine *)));
-			connect(m_subtitle, SIGNAL(lineHideTimeChanged(SubtitleLine *, const Time &)), this, SLOT(onLineChanged(SubtitleLine *)));
+			connect(m_subtitle, &Subtitle::lineAnchorChanged, this, &LinesModel::onLineChanged);
+			connect(m_subtitle, &Subtitle::lineErrorFlagsChanged, this, &LinesModel::onLineChanged);
+			connect(m_subtitle, &Subtitle::linePrimaryTextChanged, this, &LinesModel::onLineChanged);
+			connect(m_subtitle, &Subtitle::lineSecondaryTextChanged, this, &LinesModel::onLineChanged);
+			connect(m_subtitle, &Subtitle::lineShowTimeChanged, this, &LinesModel::onLineChanged);
+			connect(m_subtitle, &Subtitle::lineHideTimeChanged, this, &LinesModel::onLineChanged);
 		}
 	}
 }
 
+const QList<Subtitle *> &
+LinesModel::graftPoints() const
+{
+	return m_graftPoints;
+}
+
 SubtitleLine *
 LinesModel::playingLine() const
 {
@@ -211,11 +210,11 @@ LinesModel::headerData(int section, Qt::Orientation orientation, int role) const
 		return QVariant();
 
 	switch(section) {
-	case 0: return i18nc("@title:column Subtitle line number", "Line");
-	case 1: return i18nc("@title:column", "Show Time");
-	case 2: return i18nc("@title:column", "Hide Time");
-	case 3: return i18nc("@title:column Subtitle line (primary) text", "Text");
-	case 4: return i18nc("@title:column Subtitle line translation text", "Translation");
+	case Number: return i18nc("@title:column Subtitle line number", "Line");
+	case ShowTime: return i18nc("@title:column", "Show Time");
+	case HideTime: return i18nc("@title:column", "Hide Time");
+	case Text: return i18nc("@title:column Subtitle line (primary) text", "Text");
+	case Translation: return i18nc("@title:column Subtitle line translation text", "Translation");
 	default: return QVariant();
 	}
 }
@@ -223,7 +222,7 @@ LinesModel::headerData(int section, Qt::Orientation orientation, int role) const
 QVariant
 LinesModel::data(const QModelIndex &index, int role) const
 {
-	if(!m_subtitle /*|| ! index.isValid() || index.row() >= rowCount() || index.column() >= ColumnCount */)
+	if(!m_subtitle)
 		return QVariant();
 
 	SubtitleLine *line = m_subtitle->line(index.row());
@@ -231,48 +230,61 @@ LinesModel::data(const QModelIndex &index, int role) const
 	if(role == PlayingLineRole)
 		return line == m_playingLine;
 
+	if(role == AnchoredRole) {
+		const QList<const SubtitleLine *> &anchors = m_subtitle->anchoredLines();
+		return anchors.empty() ? 0 : (anchors.indexOf(line) != -1 ? 1 : -1);
+	}
+
 	switch(index.column()) {
 	case Number:
 		if(role == Qt::DisplayRole)
 			return index.row() + 1;
+		if(role == Qt::SizeHintRole)
+			return QSize(QFontMetrics(QFont()).width(QString::number(index.row() + 1)) + 28, 0);
 		break;
+
 	case ShowTime:
-		// if ( role == Qt::DisplayRole || role == Qt::ToolTipRole )
 		if(role == Qt::DisplayRole)
 			return line->showTime().toString();
-		else if(role == Qt::TextAlignmentRole)
+		if(role == Qt::TextAlignmentRole)
 			return Qt::AlignCenter;
 		break;
+
 	case HideTime:
-		// if ( role == Qt::DisplayRole || role == Qt::ToolTipRole )
 		if(role == Qt::DisplayRole)
 			return line->hideTime().toString();
-		else if(role == Qt::TextAlignmentRole)
+		if(role == Qt::TextAlignmentRole)
 			return Qt::AlignCenter;
 		break;
-	case Text: if(role == Qt::DisplayRole)
+
+	case Text:
+		if(role == Qt::DisplayRole)
 			return line->primaryText().richString();
-		else if(role == MarkedRole)
+		if(role == MarkedRole)
 			return line->errorFlags() & SubtitleLine::UserMark;
-		else if(role == ErrorRole)
+		if(role == ErrorRole)
 			return line->errorFlags() & ((SubtitleLine::SharedErrors | SubtitleLine::PrimaryOnlyErrors) & ~SubtitleLine::UserMark);
-		else if(role == Qt::ToolTipRole)
+		if(role == Qt::ToolTipRole)
 			return buildToolTip(m_subtitle->line(index.row()), true);
-		else if(role == Qt::EditRole)
+		if(role == Qt::EditRole)
 			return m_subtitle->line(index.row())->primaryText().richString().replace('\n', '|');
 		break;
-	case Translation: if(role == Qt::DisplayRole)
+
+	case Translation:
+		if(role == Qt::DisplayRole)
 			return m_subtitle->line(index.row())->secondaryText().richString();
-		else if(role == MarkedRole)
+		if(role == MarkedRole)
 			return line->errorFlags() & SubtitleLine::UserMark;
-		else if(role == ErrorRole)
+		if(role == ErrorRole)
 			return line->errorFlags() & ((SubtitleLine::SharedErrors | SubtitleLine::SecondaryOnlyErrors) & ~SubtitleLine::UserMark);
-		else if(role == Qt::ToolTipRole)
+		if(role == Qt::ToolTipRole)
 			return buildToolTip(m_subtitle->line(index.row()), false);
-		else if(role == Qt::EditRole)
+		if(role == Qt::EditRole)
 			return m_subtitle->line(index.row())->secondaryText().richString().replace('\n', '|');
 		break;
-	default: break;
+
+	default:
+		break;
 	}
 	return QVariant();
 }
@@ -328,7 +340,7 @@ LinesModel::onLinesRemoved(int firstIndex, int lastIndex)
 }
 
 void
-LinesModel::onLineChanged(SubtitleLine *line)
+LinesModel::onLineChanged(const SubtitleLine *line)
 {
 	int lineIndex = line->index();
 
@@ -489,7 +501,7 @@ LinesItemDelegate::drawBackgroundPrimitive(QPainter *painter, const QStyle *styl
 }
 
 void
-LinesItemDelegate::drawTextPrimitive(QPainter *painter, const QStyle *style, const QStyleOptionViewItemV4 &option, const QRect &rect, QPalette::ColorGroup cg) const
+LinesItemDelegate::drawTextPrimitive(QPainter *painter, const QStyle *style, const QStyleOptionViewItemV4 &option, const QRect &rect, QPalette::ColorGroup cg, const QModelIndex &index) const
 {
 	const int textMargin = style->pixelMetric(QStyle::PM_FocusFrameHMargin, 0, option.widget) + 1;
 	const int alignment = QStyle::visualAlignment(option.direction, option.displayAlignment);
@@ -511,8 +523,7 @@ LinesItemDelegate::drawTextPrimitive(QPainter *painter, const QStyle *style, con
 		m_textDocument->setHtml("<p>" + text + "</p>");
 
 		QPalette palette(option.palette);
-		palette.setColor(QPalette::Text, palette.color(cg, option.state & QStyle::State_Selected ? QPalette::HighlightedText : QPalette::Text)
-						 );
+		palette.setColor(QPalette::Text, palette.color(cg, option.state & QStyle::State_Selected ? QPalette::HighlightedText : QPalette::Text));
 
 		QAbstractTextDocumentLayout::PaintContext context;
 		context.palette = palette;
@@ -521,10 +532,32 @@ LinesItemDelegate::drawTextPrimitive(QPainter *painter, const QStyle *style, con
 		m_textDocument->documentLayout()->draw(painter, context);
 		painter->translate(-textRect.x() + TEXT_DOCUMENT_CORRECTION, -textRect.y() + TEXT_DOCUMENT_CORRECTION);
 	} else {
+		QColor textColor;
 		if(option.state & QStyle::State_Selected)
-			painter->setPen(option.palette.color(cg, QPalette::HighlightedText));
+			textColor = option.palette.color(cg, QPalette::HighlightedText);
 		else
-			painter->setPen(option.palette.color(cg, QPalette::Text));
+			textColor = option.palette.color(cg, QPalette::Text);
+
+		if(index.column() == LinesModel::ShowTime && index.data(LinesModel::AnchoredRole).toInt() == -1)
+			textColor.setAlpha(50);
+
+		painter->setPen(textColor);
+
+		if(index.column() == LinesModel::Number && index.data(LinesModel::AnchoredRole).toInt() == 1) {
+			int iconSize = qMin(textRect.width(), textRect.height()) - 3;
+			QRect iconRect = QRect(textRect.right() - iconSize - 2, textRect.y() + 1, iconSize, iconSize);
+
+			QIcon::Mode mode = QIcon::Normal;
+			if(!(option.state & QStyle::State_Enabled))
+				mode = QIcon::Disabled;
+			else if(option.state & QStyle::State_Selected)
+				mode = QIcon::Selected;
+			QIcon::State state = option.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
+
+			textRect.setRight(textRect.right() - iconSize);
+
+			anchorIcon().paint(painter, iconRect, option.decorationAlignment, mode, state);
+		}
 
 		painter->drawText(textRect, alignment, text);
 	}
@@ -553,8 +586,9 @@ LinesItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt, con
 		if(option.state & QStyle::State_Selected) {
 			option.backgroundBrush = option.palette.highlight().color().lighter(125);
 			option.palette.setBrush(cg, QPalette::Highlight, option.backgroundBrush);
-		} else
+		} else {
 			option.backgroundBrush = option.palette.highlight().color().lighter(165);
+		}
 	}
 	drawBackgroundPrimitive(painter, style, option);
 
@@ -574,7 +608,6 @@ LinesItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt, con
 		QIcon::State state = option.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
 
 		if(showMarkedIcon) {
-			// painter->drawPixmap( iconRect, markPixmap() );
 			markIcon().paint(painter, iconRect, option.decorationAlignment, mode, state);
 			textRect.setX(textRect.x() + iconSize + 2);
 			if(showErrorIcon)
@@ -582,7 +615,6 @@ LinesItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt, con
 		}
 
 		if(showErrorIcon) {
-			// painter->drawPixmap( iconRect, errorPixmap() );
 			errorIcon().paint(painter, iconRect, option.decorationAlignment, mode, state);
 			textRect.setX(textRect.x() + iconSize + 2);
 		}
@@ -594,7 +626,7 @@ LinesItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt, con
 			painter->drawRect(textRect.adjusted(0, 0, -1, -1));
 		}
 
-		drawTextPrimitive(painter, style, option, textRect, cg);
+		drawTextPrimitive(painter, style, option, textRect, cg, index);
 	}
 	// draw the focus rect
 	if(option.state & QStyle::State_HasFocus) {
@@ -628,7 +660,7 @@ LinesItemDelegate::markIcon()
 {
 	static QIcon markIcon;
 	if(markIcon.isNull())
-		markIcon = KIcon("dialog-warning");
+		markIcon = QIcon::fromTheme("dialog-warning");
 	return markIcon;
 }
 
@@ -637,10 +669,19 @@ LinesItemDelegate::errorIcon()
 {
 	static QIcon errorIcon;
 	if(errorIcon.isNull())
-		errorIcon = KIcon("dialog-error");
+		errorIcon = QIcon::fromTheme("dialog-error");
 	return errorIcon;
 }
 
+const QIcon &
+LinesItemDelegate::anchorIcon()
+{
+	static QIcon anchorIcon;
+	if(anchorIcon.isNull())
+		anchorIcon = QIcon(QStringLiteral(CUSTOM_ICON_INSTALL_PATH "anchor"));
+	return anchorIcon;
+}
+
 const QPixmap &
 LinesItemDelegate::markPixmap()
 {
@@ -676,13 +717,13 @@ LinesWidget::LinesWidget(QWidget *parent) :
 		setItemDelegateForColumn(column, column < LinesModel::Text ? plainTextDelegate : richTextDelegate);
 
 	QHeaderView *header = this->header();
-	header->setClickable(false);
-	header->setMovable(false);
-	header->setResizeMode(LinesModel::Number, QHeaderView::ResizeToContents);
-	header->setResizeMode(LinesModel::ShowTime, QHeaderView::ResizeToContents);
-	header->setResizeMode(LinesModel::HideTime, QHeaderView::ResizeToContents);
-	header->setResizeMode(LinesModel::Text, QHeaderView::Interactive);
-	header->setResizeMode(LinesModel::Translation, QHeaderView::Interactive);
+	header->setSectionsClickable(false);
+	header->setSectionsMovable(false);
+	header->setSectionResizeMode(LinesModel::Number, QHeaderView::ResizeToContents);
+	header->setSectionResizeMode(LinesModel::ShowTime, QHeaderView::ResizeToContents);
+	header->setSectionResizeMode(LinesModel::HideTime, QHeaderView::ResizeToContents);
+	header->setSectionResizeMode(LinesModel::Text, QHeaderView::Interactive);
+	header->setSectionResizeMode(LinesModel::Translation, QHeaderView::Interactive);
 	header->setSectionHidden(LinesModel::Translation, true);
 
 	setUniformRowHeights(true);
@@ -912,10 +953,10 @@ LinesWidget::targetRanges(int target) const
 void
 LinesWidget::loadConfig()
 {
-	KConfigGroup group(KGlobal::config()->group("LinesWidget Settings"));
+	KConfigGroup group(KSharedConfig::openConfig()->group("LinesWidget Settings"));
 
 	QByteArray state;
-	QStringList strState = group.readXdgListEntry("Columns State", QString("").split(' '));
+	QStringList strState = group.readXdgListEntry("Columns State", QStringList() << QString());
 	for(QStringList::ConstIterator it = strState.begin(), end = strState.end(); it != end; ++it)
 		state.append((char)(*it).toInt());
 	header()->restoreState(state);
@@ -924,7 +965,7 @@ LinesWidget::loadConfig()
 void
 LinesWidget::saveConfig()
 {
-	KConfigGroup group(KGlobal::config()->group("LinesWidget Settings"));
+	KConfigGroup group(KSharedConfig::openConfig()->group("LinesWidget Settings"));
 
 	QStringList strState;
 	QByteArray state = header()->saveState();
@@ -986,37 +1027,29 @@ bool
 LinesWidget::eventFilter(QObject *object, QEvent *event)
 {
 	if(object == viewport()) {
-		if(event->type() == QEvent::DragEnter) {
-			QDragEnterEvent *dragEnterEvent = static_cast<QDragEnterEvent *>(event);
-			KUrl::List urls = KUrl::List::fromMimeData(dragEnterEvent->mimeData());
-			if(!urls.isEmpty())
-				dragEnterEvent->accept();
-			else
-				dragEnterEvent->ignore();
-			return true;
-		} else if(event->type() == QEvent::DragMove) {
-			return true;            // eat event
-		} else if(event->type() == QEvent::Drop) {
-			QDropEvent *dropEvent = static_cast<QDropEvent *>(event);
-
-			KUrl::List urls = KUrl::List::fromMimeData(dropEvent->mimeData());
-			if(!urls.isEmpty()) {
-				for(KUrl::List::ConstIterator it = urls.begin(), end = urls.end(); it != end; ++it) {
-					const KUrl &url = *it;
-
-					if(url.protocol() != "file")
-						continue;
-
-					app()->openSubtitle(*it);
-					break;
+		switch(event->type()) {
+		case QEvent::DragEnter:
+		case QEvent::Drop:
+			foreach(const QUrl &url, static_cast<QDropEvent *>(event)->mimeData()->urls()) {
+				if(url.scheme() == QLatin1String("file")) {
+					event->accept();
+					if(event->type() == QEvent::Drop) {
+						app()->openSubtitle(url);
+					}
+					return true; // eat event
 				}
 			}
+			event->ignore();
+			return true;
 
-			return true;            // eat event
-		} else
-			return TreeView::eventFilter(object, event); // standard event processing
+		case QEvent::DragMove:
+			return true; // eat event
+
+		default:
+			;
+		}
 	}
-
+	// standard event processing
 	return TreeView::eventFilter(object, event);
 }
 
@@ -1037,7 +1070,7 @@ LinesWidget::contextMenuEvent(QContextMenuEvent *e)
 	Application *app = Application::instance();
 	QAction *action;
 
-	KMenu textsMenu(i18n("Texts"));
+	QMenu textsMenu(i18n("Texts"));
 	textsMenu.addAction(i18n("Break Lines..."), app, SLOT(breakLines()));
 	textsMenu.addAction(m_translationMode ? i18n("Unbreak Lines...") : i18n("Unbreak Lines"), app, SLOT(unbreakTexts()));
 	textsMenu.addAction(m_translationMode ? i18n("Simplify Spaces...") : i18n("Simplify Spaces"), app, SLOT(simplifySpaces()));
@@ -1045,26 +1078,26 @@ LinesWidget::contextMenuEvent(QContextMenuEvent *e)
 	textsMenu.addAction(i18n("Fix Punctuation..."), app, SLOT(fixPunctuation()));
 	textsMenu.addAction(i18n("Translate..."), app, SLOT(translate()));
 	textsMenu.addSeparator();
-	textsMenu.addAction(KIcon("tools-check-spelling"), i18n("Spelling..."), app, SLOT(spellCheck()));
+	textsMenu.addAction(QIcon::fromTheme("tools-check-spelling"), i18n("Spelling..."), app, SLOT(spellCheck()));
 
-	KMenu stylesMenu(i18n("Styles"));
+	QMenu stylesMenu(i18n("Styles"));
 	int styleFlags = referenceLine->primaryText().cummulativeStyleFlags() | referenceLine->secondaryText().cummulativeStyleFlags();
-	action = stylesMenu.addAction(KIcon("format-text-bold"), i18nc("@action:inmenu Toggle bold style", "Bold"), app, SLOT(toggleSelectedLinesBold()));
+	action = stylesMenu.addAction(QIcon::fromTheme("format-text-bold"), i18nc("@action:inmenu Toggle bold style", "Bold"), app, SLOT(toggleSelectedLinesBold()));
 	action->setCheckable(true);
 	action->setChecked(styleFlags & SString::Bold);
-	action = stylesMenu.addAction(KIcon("format-text-italic"), i18nc("@action:inmenu Toggle italic style", "Italic"), app, SLOT(toggleSelectedLinesItalic()));
+	action = stylesMenu.addAction(QIcon::fromTheme("format-text-italic"), i18nc("@action:inmenu Toggle italic style", "Italic"), app, SLOT(toggleSelectedLinesItalic()));
 	action->setCheckable(true);
 	action->setChecked(styleFlags & SString::Italic);
-	action = stylesMenu.addAction(KIcon("format-text-underline"), i18nc("@action:inmenu Toggle underline style", "Underline"), app, SLOT(toggleSelectedLinesUnderline()));
+	action = stylesMenu.addAction(QIcon::fromTheme("format-text-underline"), i18nc("@action:inmenu Toggle underline style", "Underline"), app, SLOT(toggleSelectedLinesUnderline()));
 	action->setCheckable(true);
 	action->setChecked(styleFlags & SString::Underline);
-	action = stylesMenu.addAction(KIcon("format-text-strikethrough"), i18nc("@action:inmenu Toggle strike through style", "Strike Through"), app, SLOT(toggleSelectedLinesStrikeThrough()));
+	action = stylesMenu.addAction(QIcon::fromTheme("format-text-strikethrough"), i18nc("@action:inmenu Toggle strike through style", "Strike Through"), app, SLOT(toggleSelectedLinesStrikeThrough()));
 	action->setCheckable(true);
 	action->setChecked(styleFlags & SString::StrikeThrough);
-	action = stylesMenu.addAction(KIcon("format-text-color"), i18nc("@action:inmenu Change Text Color", "Text Color"), app, SLOT(changeSelectedLinesColor()));
+	action = stylesMenu.addAction(QIcon::fromTheme("format-text-color"), i18nc("@action:inmenu Change Text Color", "Text Color"), app, SLOT(changeSelectedLinesColor()));
 
-	KMenu timesMenu(i18n("Times"));
-	QString shiftMillis(app->generalConfig()->linesQuickShiftAmount());
+	QMenu timesMenu(i18n("Times"));
+	QString shiftMillis(SCConfig::linesQuickShiftAmount());
 	timesMenu.addAction(i18n("Shift +%1 Milliseconds", shiftMillis), app, SLOT(shiftSelectedLinesForwards()));
 	timesMenu.addAction(i18n("Shift −%1 Milliseconds", shiftMillis), app, SLOT(shiftSelectedLinesBackwards()));
 	timesMenu.addSeparator();
@@ -1075,17 +1108,17 @@ LinesWidget::contextMenuEvent(QContextMenuEvent *e)
 	timesMenu.addAction(i18n("Maximize Durations"), app, SLOT(maximizeDurations()));
 	timesMenu.addAction(i18n("Fix Overlapping Times"), app, SLOT(fixOverlappingLines()));
 
-	KMenu errorsMenu(i18n("Errors"));
+	QMenu errorsMenu(i18n("Errors"));
 	action = errorsMenu.addAction(i18n("Mark"), app, SLOT(toggleSelectedLinesMark()));
 	action->setCheckable(true);
 	action->setChecked(referenceLine->errorFlags() & SubtitleLine::UserMark);
 	errorsMenu.addSeparator();
-	errorsMenu.addAction(i18n("Check Errors..."), app, SLOT(checkErrors()));
+	errorsMenu.addAction(i18n("Check Errors..."), app, SLOT(checqCriticals()));
 	errorsMenu.addAction(i18n("Clear Errors..."), app, SLOT(clearErrors()));
 	errorsMenu.addSeparator();
 	errorsMenu.addAction(i18n("Show Errors..."), app, SLOT(showErrors()));
 
-	KMenu menu;
+	QMenu menu;
 	menu.addAction(i18n("Select All"), app, SLOT(selectAllLines()));
 	menu.addSeparator();
 	menu.addAction(i18n("Remove"), app, SLOT(removeSelectedLines()));
@@ -1189,4 +1222,4 @@ LinesWidgetScrollToModelDetacher::~LinesWidgetScrollToModelDetacher()
 	m_linesWidget.m_scrollFollowsModel = true;
 }
 
-#include "lineswidget.moc"
+
