@@ -1,52 +1,52 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "playerwidget.h"
 #include "application.h"
-#include "configs/playerconfig.h"
 #include "actions/useractionnames.h"
 #include "../common/commondefs.h"
 #include "../core/subtitleiterator.h"
-#include "../services/player.h"
+#include "../videoplayer/videoplayer.h"
 #include "../widgets/layeredwidget.h"
 #include "../widgets/textoverlaywidget.h"
 #include "../widgets/attachablewidget.h"
 #include "../widgets/pointingslider.h"
 #include "../widgets/timeedit.h"
 
-#include <QtCore/QEvent>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QDropEvent>
-#include <QtGui/QKeyEvent>
+#include <QEvent>
+#include <QDropEvent>
+#include <QMimeData>
+#include <QKeyEvent>
 
-#include <QtGui/QDesktopWidget>
-#include <QtGui/QCursor>
-#include <QtGui/QLabel>
-#include <QtGui/QToolButton>
-#include <QtGui/QGroupBox>
-#include <QtGui/QGridLayout>
+#include <QMenu>
+#include <QPushButton>
+#include <QDesktopWidget>
+#include <QCursor>
+#include <QLabel>
+#include <QToolButton>
+#include <QGroupBox>
+#include <QGridLayout>
 
-#include <KLocale>
 #include <KConfigGroup>
 #include <KMessageBox>
-#include <KMenu>
-#include <KPushButton>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
@@ -64,22 +64,21 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	m_playingLine(0),
 	m_fullScreenTID(0),
 	m_fullScreenMode(false),
-	m_player(Player::instance()),
+	m_player(VideoPlayer::instance()),
 	m_lengthString(UNKNOWN_LENGTH_STRING),
 	m_updatePositionControls(1),
 	m_updateVideoPosition(false),
 	m_updateVolumeControls(true),
 	m_updatePlayerVolume(false),
-	m_showPositionTimeEdit(app()->playerConfig()->showPositionTimeEdit())
+	m_showPositionTimeEdit(SCConfig::showPositionTimeEdit())
 {
 	m_layeredWidget = new LayeredWidget(this);
 	m_layeredWidget->setAcceptDrops(true);
 	m_layeredWidget->installEventFilter(this);
 	m_layeredWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-	m_player->initialize(m_layeredWidget, app()->playerConfig()->playerBackend());
-
-	connect(m_player, SIGNAL(backendInitialized(ServiceBackend *)), this, SLOT(onPlayerBackendInitialized()));
+	m_player->initialize(m_layeredWidget, SCConfig::playerBackend());
+	connect(m_player, SIGNAL(backendInitialized(PlayerBackend *)), this, SLOT(onPlayerBackendInitialized()));
 
 	m_textOverlay = new TextOverlayWidget(m_layeredWidget);
 	m_textOverlay->setAlignment(Qt::AlignHCenter | Qt::AlignBottom);
@@ -92,7 +91,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	m_seekSlider->setPageStep(10);
 	m_seekSlider->setFocusPolicy(Qt::NoFocus);
 
-	m_infoControlsGroupBox = new QGroupBox(this);
+	m_infoControlsGroupBox = new QWidget(this);
 	m_infoControlsGroupBox->setAcceptDrops(true);
 	m_infoControlsGroupBox->installEventFilter(this);
 
@@ -236,12 +235,12 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	connect(m_positionEdit, SIGNAL(valueChanged(int)), this, SLOT(onPositionEditValueChanged(int)));
 	connect(m_positionEdit, SIGNAL(valueEntered(int)), this, SLOT(onPositionEditValueChanged(int)));
 
-	connect(app()->playerConfig(), SIGNAL(optionChanged(const QString &, const QString &)), this, SLOT(onPlayerOptionChanged(const QString &, const QString &)));
+	connect(SCConfig::self(), SIGNAL(configChanged()), this, SLOT(onConfigChanged()));
 
 	connect(m_player, SIGNAL(fileOpened(const QString &)), this, SLOT(onPlayerFileOpened(const QString &)));
-	connect(m_player, SIGNAL(fileOpenError(const QString &)), this, SLOT(onPlayerFileOpenError(const QString &)));
+	connect(m_player, SIGNAL(fileOpenError(QString,QString)), this, SLOT(onPlayerFileOpenError(QString,QString)));
 	connect(m_player, SIGNAL(fileClosed()), this, SLOT(onPlayerFileClosed()));
-	connect(m_player, SIGNAL(playbackError(const QString &)), this, SLOT(onPlayerPlaybackError(const QString &)));
+	connect(m_player, SIGNAL(playbacqCritical(const QString &)), this, SLOT(onPlayerPlaybacqCritical(const QString &)));
 	connect(m_player, SIGNAL(playing()), this, SLOT(onPlayerPlaying()));
 	connect(m_player, SIGNAL(stopped()), this, SLOT(onPlayerStopped()));
 	connect(m_player, SIGNAL(positionChanged(double)), this, SLOT(onPlayerPositionChanged(double)));
@@ -255,7 +254,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 
 	setOverlayLine(0);
 	onPlayerFileClosed();
-	onPlayerOptionChanged(QString(), QString());    // initializes the font
+	onConfigChanged();    // initializes the font
 }
 
 PlayerWidget::~PlayerWidget()
@@ -265,6 +264,12 @@ PlayerWidget::~PlayerWidget()
 	m_fullScreenControls->deleteLater();
 }
 
+QWidget *
+PlayerWidget::infoSidebarWidget()
+{
+	return m_infoControlsGroupBox;
+}
+
 QToolButton *
 PlayerWidget::toolButton(QWidget *parent, const char *name)
 {
@@ -309,14 +314,27 @@ PlayerWidget::setFullScreenMode(bool fullScreenMode)
 			increaseFontSize(18);
 
 			window()->hide();
-			m_layeredWidget->setParent(0);  // removes the widget from this window (and this m_mainLayout)
-			m_layeredWidget->showFullScreen();      // krazy:exclude=c++/qmethods
+
+			// Move m_layeredWidget to a temporary widget which will be
+			// displayed in full screen mode.
+			// Can not call showFullScreen() on m_layeredWidget directly
+			// because restoring the previous state is buggy under
+			// some desktop environments / window managers.
+
+			auto *fullScreenWidget = new QWidget;
+			auto *fullScreenLayout = new QHBoxLayout;
+			fullScreenLayout->setMargin(0);
+			fullScreenWidget->setLayout(fullScreenLayout);
+			m_layeredWidget->setParent(fullScreenWidget);
+			fullScreenLayout->addWidget(m_layeredWidget);
+			fullScreenWidget->showFullScreen();
 
 			m_layeredWidget->unsetCursor();
 			m_layeredWidget->setMouseTracking(true);
 			m_fullScreenControls->attach(m_layeredWidget);
 
 			m_fullScreenTID = startTimer(HIDE_MOUSE_MSECS);
+
 		} else {
 			if(m_fullScreenTID) {
 				killTimer(m_fullScreenTID);
@@ -329,11 +347,13 @@ PlayerWidget::setFullScreenMode(bool fullScreenMode)
 			m_layeredWidget->setMouseTracking(false);
 			m_layeredWidget->unsetCursor();
 
-			window()->show();
+			// delete temporary parent widget later and set this as parent again
+			m_layeredWidget->parent()->deleteLater();
 			m_layeredWidget->setParent(this);
-			m_layeredWidget->showNormal();  // krazy:exclude=c++/qmethods
 
 			m_mainLayout->addWidget(m_layeredWidget, 0, 1);
+
+			window()->show();
 		}
 	}
 }
@@ -392,41 +412,33 @@ bool
 PlayerWidget::eventFilter(QObject *object, QEvent *event)
 {
 	if(object == m_layeredWidget) {
-		if(event->type() == QEvent::DragEnter) {
-			QDragEnterEvent *dragEnterEvent = static_cast<QDragEnterEvent *>(event);
-			KUrl::List urls = KUrl::List::fromMimeData(dragEnterEvent->mimeData());
-			if(!urls.isEmpty())
-				dragEnterEvent->accept();
-			else
-				dragEnterEvent->ignore();
-			return true;
-		} else if(event->type() == QEvent::DragMove) {
-			return true;            // eat event
-		} else if(event->type() == QEvent::Drop) {
-			QDropEvent *dropEvent = static_cast<QDropEvent *>(event);
-
-			KUrl::List urls = KUrl::List::fromMimeData(dropEvent->mimeData());
-			if(!urls.isEmpty()) {
-				for(KUrl::List::ConstIterator it = urls.begin(), end = urls.end(); it != end; ++it) {
-					const KUrl &url = *it;
-
-					if(url.protocol() != "file")
-						continue;
-
-					app()->openVideo(url);
-					break;
+		switch(event->type()) {
+		case QEvent::DragEnter:
+		case QEvent::Drop:
+			foreach(const QUrl &url, static_cast<QDropEvent *>(event)->mimeData()->urls()) {
+				if(url.scheme() == QLatin1String("file")) {
+					event->accept();
+					if(event->type() == QEvent::Drop) {
+						app()->openVideo(url);
+					}
+					return true; // eat event
 				}
 			}
+			event->ignore();
+			return true;
 
-			return true;            // eat event
-		} else if(event->type() == QEvent::KeyPress) {
+		case QEvent::DragMove:
+			return true; // eat event
+
+		case QEvent::KeyPress: {
 			// NOTE: when on full screen mode, the keyboard input is received but
 			// for some reason it doesn't trigger the correct actions automatically
 			// so we process the event and handle the issue ourselves.
-
 			QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
 			return app()->triggerAction(QKeySequence((keyEvent->modifiers() & ~Qt::KeypadModifier) + keyEvent->key()));
-		} else if(event->type() == QEvent::MouseMove) {
+		}
+
+		case QEvent::MouseMove: {
 			QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
 			if(mouseEvent->globalPos() != m_currentCursorPos) {
 				m_currentCursorPos = mouseEvent->globalPos();
@@ -435,28 +447,34 @@ PlayerWidget::eventFilter(QObject *object, QEvent *event)
 				if(m_fullScreenControls->isAttached())
 					m_fullScreenControls->toggleVisible(true);
 			}
+			break;
 		}
+
+		default:
+			;
+		}
+
 	} else if(object == m_infoControlsGroupBox || object->parent() == m_infoControlsGroupBox) {
 		if(event->type() != QEvent::MouseButtonRelease)
-			return QWidget::eventFilter(object, event);
+			return false;
 
 		QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
 
 		if(mouseEvent->button() != Qt::RightButton)
-			return QWidget::eventFilter(object, event);
+			return false;
 
-		KMenu menu;
+		QMenu menu;
 		QAction *action = menu.addAction(i18n("Show editable position control"));
 		action->setCheckable(true);
-		action->setChecked(app()->playerConfig()->showPositionTimeEdit());
+		action->setChecked(SCConfig::showPositionTimeEdit());
 
 		if(menu.exec(mouseEvent->globalPos()) == action)
-			app()->playerConfig()->toggleShowPositionTimeEdit();
+			SCConfig::setShowPositionTimeEdit(!SCConfig::showPositionTimeEdit());
 
-		return true;                    // eat event
+		return true; // eat event
 	}
 
-	return QWidget::eventFilter(object, event);
+	return false;
 }
 
 void
@@ -503,13 +521,13 @@ PlayerWidget::setShowTranslation(bool showTranslation)
 void
 PlayerWidget::increaseFontSize(int points)
 {
-	app()->playerConfig()->incFontPointSize(points);
+	SCConfig::setFontPointSize(SCConfig::fontPointSize() + points);
 }
 
 void
 PlayerWidget::decreaseFontSize(int points)
 {
-	app()->playerConfig()->incFontPointSize(-points);
+	SCConfig::setFontPointSize(SCConfig::fontPointSize() - points);
 }
 
 void
@@ -598,7 +616,7 @@ PlayerWidget::setPlayingLine(SubtitleLine *line)
 void
 PlayerWidget::updatePositionEditVisibility()
 {
-	if(m_showPositionTimeEdit && (m_player->state() == Player::Playing || m_player->state() == Player::Paused))
+	if(m_showPositionTimeEdit && (m_player->state() == VideoPlayer::Playing || m_player->state() == VideoPlayer::Paused))
 		m_positionEdit->show();
 	else
 		m_positionEdit->hide();
@@ -668,20 +686,24 @@ PlayerWidget::onPositionEditValueChanged(int position)
 }
 
 void
-PlayerWidget::onPlayerOptionChanged(const QString &option, const QString &value)
+PlayerWidget::onConfigChanged()
 {
-	if(option == PlayerConfig::keyPlayerBackend()) {
-		m_player->reinitialize(value);
-	} else if(option == PlayerConfig::keyShowPositionTimeEdit()) {
-		m_showPositionTimeEdit = (value == "true");
+	if(m_player->backend(SCConfig::playerBackend()) != m_player->activeBackend())
+		m_player->reinitialize(SCConfig::playerBackend());
+	else
+		m_player->reconfigure();
+
+	if(m_showPositionTimeEdit != SCConfig::showPositionTimeEdit()) {
+		m_showPositionTimeEdit = SCConfig::showPositionTimeEdit();
 		updatePositionEditVisibility();
-	} else {
-		m_textOverlay->setPrimaryColor(app()->playerConfig()->fontColor());
-		m_textOverlay->setFamily(app()->playerConfig()->fontFamily());
-		m_textOverlay->setPointSize(app()->playerConfig()->fontPointSize());
-		m_textOverlay->setOutlineColor(app()->playerConfig()->outlineColor());
-		m_textOverlay->setOutlineWidth(app()->playerConfig()->outlineWidth());
 	}
+
+	m_textOverlay->setPrimaryColor(SCConfig::fontColor());
+	m_textOverlay->setFamily(SCConfig::fontFamily());
+	m_textOverlay->setPointSize(SCConfig::fontPointSize());
+	m_textOverlay->setOutlineColor(SCConfig::outlineColor());
+	m_textOverlay->setOutlineWidth(SCConfig::outlineWidth());
+	m_textOverlay->setAntialias(SCConfig::antialias());
 }
 
 void
@@ -701,9 +723,12 @@ PlayerWidget::onPlayerFileOpened(const QString & /*filePath */)
 }
 
 void
-PlayerWidget::onPlayerFileOpenError(const QString &filePath)
+PlayerWidget::onPlayerFileOpenError(const QString &filePath, const QString &reason)
 {
-	KMessageBox::sorry(this, i18n("<qt>There was an error opening media file %1.</qt>", filePath));
+	QString message = i18n("<qt>There was an error opening media file %1.</qt>", filePath);
+	if(!reason.isEmpty())
+		message += "\n" + reason;
+	KMessageBox::sorry(this, message);
 }
 
 void
@@ -729,14 +754,12 @@ PlayerWidget::onPlayerFileClosed()
 }
 
 void
-PlayerWidget::onPlayerPlaybackError(const QString &errorMessage)
+PlayerWidget::onPlayerPlaybacqCritical(const QString &errorMessage)
 {
 	if(errorMessage.isEmpty())
-		KMessageBox::error(this, i18n("Unexpected error when playing file."), i18n("Error Playing File")
-		                   );
+		KMessageBox::error(this, i18n("Unexpected error when playing file."), i18n("Error Playing File"));
 	else
-		KMessageBox::detailedError(this, i18n("Unexpected error when playing file."), errorMessage, i18n("Error Playing File")
-		                           );
+		KMessageBox::detailedError(this, i18n("Unexpected error when playing file."), errorMessage, i18n("Error Playing File"));
 	// onPlayerFileClosed();
 }
 
@@ -829,7 +852,7 @@ PlayerWidget::onPlayerLeftClicked(const QPoint & /*point */)
 void
 PlayerWidget::onPlayerRightClicked(const QPoint &point)
 {
-	static KMenu *menu = new KMenu(this);
+	static QMenu *menu = new QMenu(this);
 
 	menu->clear();
 
@@ -889,4 +912,4 @@ PlayerWidget::onPlayerBackendInitialized()
 	m_textOverlay->raise();
 }
 
-#include "playerwidget.moc"
+
