@@ -1,24 +1,25 @@
 #ifndef PLAYERWIDGET_H
 #define PLAYERWIDGET_H
 
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -28,21 +29,21 @@
 #include "../core/subtitle.h"
 #include "../core/subtitleline.h"
 
-#include <QtCore/QPoint>
-#include <QtGui/QWidget>
+#include <QPoint>
+#include <QWidget>
+
+QT_FORWARD_DECLARE_CLASS(QGridLayout)
+QT_FORWARD_DECLARE_CLASS(QLabel)
+QT_FORWARD_DECLARE_CLASS(QToolButton)
+QT_FORWARD_DECLARE_CLASS(QSlider)
 
 class LayeredWidget;
 class TextOverlayWidget;
 class AttachableWidget;
 class TimeEdit;
-class QGridLayout;
-class QGroupBox;
-class QLabel;
-class QToolButton;
-class QSlider;
 
 namespace SubtitleComposer {
-class Player;
+class VideoPlayer;
 
 class PlayerWidget : public QWidget
 {
@@ -65,6 +66,8 @@ public:
 
 	virtual bool eventFilter(QObject *object, QEvent *event);
 
+	QWidget *infoSidebarWidget();
+
 public slots:
 	void setSubtitle(Subtitle *subtitle = 0);
 	void setTranslationMode(bool enabled);
@@ -99,12 +102,12 @@ private slots:
 	void onSeekSliderReleased();
 	void onPositionEditValueChanged(int position);
 
-	void onPlayerOptionChanged(const QString &option, const QString &value);
+	void onConfigChanged();
 
 	void onPlayerFileOpened(const QString &filePath);
-	void onPlayerFileOpenError(const QString &filePath);
+	void onPlayerFileOpenError(const QString &filePath, const QString &reason);
 	void onPlayerFileClosed();
-	void onPlayerPlaybackError(const QString &errorMessage);
+	void onPlayerPlaybacqCritical(const QString &errorMessage);
 	void onPlayerPlaying();
 	void onPlayerStopped();
 	void onPlayerPositionChanged(double seconds);
@@ -127,7 +130,7 @@ private:
 
 	int m_fullScreenTID;
 	bool m_fullScreenMode;
-	Player *m_player;
+	VideoPlayer *m_player;
 
 	Time m_lastSearchedLineToShowTime;
 	Time m_lastCheckedTime;
@@ -150,7 +153,7 @@ private:
 	bool m_updateVolumeControls;
 	bool m_updatePlayerVolume;
 
-	QGroupBox *m_infoControlsGroupBox;
+	QWidget *m_infoControlsGroupBox;
 	QLabel *m_positionLabel;
 	TimeEdit *m_positionEdit;
 	bool m_showPositionTimeEdit;
