@@ -19,7 +19,7 @@
 
 #include "scripting_sstring.h"
 
-#include <QtCore/QRegExp>
+#include <QRegExp>
 
 using namespace SubtitleComposer;
 
@@ -341,4 +341,4 @@ Scripting::SString::compareToPlain(const QString &string) const
 		return 1;
 }
 
-#include "scripting_sstring.moc"
+
