@@ -28,7 +28,7 @@
 #include "../../core/subtitle.h"
 #include "../../core/rangelist.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 namespace SubtitleComposer {
 class Subtitle;
@@ -88,9 +88,9 @@ public slots:
 
 	void clearErrors(const QObject *ranges, int errorFlags);
 
-	void checkErrors(const QObject *ranges, int errorFlags, int minDuration, int maxDuration, int minDurationPerChar, int maxDurationPerChar, int maxChars, int maxLines);
+	void checqCriticals(const QObject *ranges, int errorFlags, int minDuration, int maxDuration, int minDurationPerChar, int maxDurationPerChar, int maxChars, int maxLines);
 
-	void recheckErrors(const QObject *ranges, int minDuration, int maxDuration, int minDurationPerChar, int maxDurationPerChar, int maxChars, int maxLines);
+	void rechecqCriticals(const QObject *ranges, int minDuration, int maxDuration, int minDurationPerChar, int maxDurationPerChar, int maxChars, int maxLines);
 
 private:
 	static SubtitleComposer::RangeList toRangesList(const QObject *object);
