@@ -26,7 +26,7 @@
 
 #include "../../core/subtitle.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
 namespace SubtitleComposer {
 class FindErrorsDialog;
