@@ -1,36 +1,35 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "finder.h"
 #include "../../core/subtitleiterator.h"
 
-#include <QtGui/QGroupBox>
-#include <QtGui/QRadioButton>
-#include <QtGui/QGridLayout>
-
-#include <KDebug>
-#include <KLocale>
+#include <QGroupBox>
+#include <QRadioButton>
+#include <QGridLayout>
+#include <QDebug>
 
 #include <KMessageBox>
-
 #include <KFind>
 #include <KFindDialog>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
@@ -48,7 +47,7 @@ Finder::Finder(QWidget *parent) :
 	m_dialog->setHasCursor(true);
 	m_dialog->setOptions(m_dialog->options() | KFind::FromCursor);
 
-	QWidget *mainWidget = m_dialog->mainWidget();
+	QWidget *mainWidget = m_dialog;//->mainWidget();
 	QLayout *mainLayout = mainWidget->layout();
 
 	m_targetGroupBox = new QGroupBox(mainWidget);
@@ -76,19 +75,21 @@ Finder::Finder(QWidget *parent) :
 
 Finder::~Finder()
 {
-	delete m_dialog;
-
 	invalidate();
 }
 
 void
 Finder::invalidate()
 {
-	delete m_find;
-	m_find = 0;
+	if(m_find) {
+		delete m_find;
+		m_find = 0;
+	}
 
-	delete m_iterator;
-	m_iterator = 0;
+	if(m_iterator) {
+		delete m_iterator;
+		m_iterator = 0;
+	}
 
 	m_feedingPrimary = false;
 
@@ -248,10 +249,10 @@ Finder::advance()
 
 			// special case: we searched all lines and didn't found any matches
 			if(!m_instancesFound && (m_allSearchedIndex == m_iterator->index() || (backwards ? (m_allSearchedIndex == m_iterator->lastIndex() && m_iterator->index() == SubtitleIterator::BehindFirst) : (m_allSearchedIndex == m_iterator->firstIndex() && m_iterator->index() == SubtitleIterator::AfterLast))
-			                         ))
+									 ))
 			{
 				KMessageBox::sorry(parentWidget(), i18n("No instances of '%1' found!", m_find->pattern()), i18n("Find")
-				                   );
+								   );
 
 				invalidate();
 
@@ -265,7 +266,7 @@ Finder::advance()
 					m_iterator->toFirst();
 
 				if(KMessageBox::warningContinueCancel(parentWidget(), backwards ? (selection ? i18n("Beginning of selection reached.\nContinue from the end?") : i18n("Beginning of subtitle reached.\nContinue from the end?")) : (selection ? i18n("End of selection reached.\nContinue from the beginning?") : i18n("End of subtitle reached.\nContinue from the beginning?")), i18n("Find")
-				                                      ) != KMessageBox::Continue)
+													  ) != KMessageBox::Continue)
 					break;
 			}
 		}
@@ -324,4 +325,4 @@ Finder::onIteratorSynchronized(int firstIndex, int lastIndex, bool inserted)
 	}
 }
 
-#include "finder.moc"
+
