@@ -27,10 +27,10 @@
 #include "../../core/subtitle.h"
 #include "../../core/subtitleline.h"
 
-#include <QtCore/QObject>
+#include <QObject>
 
-class QGroupBox;
-class QRadioButton;
+QT_FORWARD_DECLARE_CLASS(QGroupBox)
+QT_FORWARD_DECLARE_CLASS(QRadioButton)
 class KFind;
 class KFindDialog;
 
