@@ -1,35 +1,37 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "replacer.h"
 #include "../../core/subtitleiterator.h"
 #include "kreplace.h"
 
-#include <QtGui/QGroupBox>
-#include <QtGui/QRadioButton>
-#include <QtGui/QGridLayout>
+#include <QGroupBox>
+#include <QRadioButton>
+#include <QGridLayout>
+#include <QDebug>
+#include <QDialog>
 
-#include <KDebug>
-#include <KLocale>
-#include <KDialog>
+#include <KFind>
 #include <KMessageBox>
 #include <KReplaceDialog>
+#include <KLocalizedString>
 
 using namespace SubtitleComposer;
 
@@ -46,7 +48,7 @@ Replacer::Replacer(QWidget *parent) :
 	m_dialog->setHasCursor(true);
 	m_dialog->setOptions(m_dialog->options() | KFind::FromCursor);
 
-	QWidget *mainWidget = m_dialog->mainWidget();
+	QWidget *mainWidget = m_dialog;//->mainWidget();
 	QLayout *mainLayout = mainWidget->layout();
 
 	m_targetGroupBox = new QGroupBox(mainWidget);
@@ -175,7 +177,7 @@ Replacer::advance()
 	bool selection = m_replace->options() & KFind::SelectedText;
 	bool backwards = m_replace->options() & KFind::FindBackwards;
 
-	KDialog *replaceNextDialog = this->replaceNextDialog(); // creates the dialog if it didn't existed before
+	QDialog *replaceNextDialog = this->replaceNextDialog(); // creates the dialog if it didn't existed before
 
 	do {
 		if(m_replace->needData()) {
@@ -209,10 +211,10 @@ Replacer::advance()
 
 				if(m_instancesFound && m_replace->numReplacements())
 					KMessageBox::information(parentWidget(), i18np("1 replacement done.", "%1 replacements done.", m_replace->numReplacements()), i18n("Replace")
-					                         );
+											 );
 				else // special case
 					KMessageBox::sorry(parentWidget(), i18n("No instances of '%1' found!", m_replace->pattern()), i18n("Replace")
-					                   );
+									   );
 
 				m_replace->resetCounts();
 				break;
@@ -229,7 +231,7 @@ Replacer::advance()
 				m_replace->resetCounts();
 
 				if(KMessageBox::warningContinueCancel(parentWidget(), i18np("1 replacement done.", "%1 replacements done.", numReplacements) + "\n\n" + (backwards ? (selection ? i18n("Beginning of selection reached.\nContinue from the end?") : i18n("Beginning of subtitle reached.\nContinue from the end?")) : (selection ? i18n("End of selection reached.\nContinue from the beginning?") : i18n("End of subtitle reached.\nContinue from the beginning?"))), i18n("Replace")
-				                                      ) != KMessageBox::Continue)
+													  ) != KMessageBox::Continue)
 				{
 					if(replaceNextDialog)
 						replaceNextDialog->hide();
@@ -240,13 +242,13 @@ Replacer::advance()
 	} while(res != KFind::Match);
 }
 
-KDialog *
+QDialog *
 Replacer::replaceNextDialog()
 {
 	if(!m_replace)
 		return 0;
 
-	KDialog *replaceNextDialog = m_replace->replaceNextDialog(false);
+	QDialog *replaceNextDialog = m_replace->replaceNextDialog(false);
 
 	if(!replaceNextDialog && m_replace->options() & KReplaceDialog::PromptOnReplace) {
 		replaceNextDialog = m_replace->replaceNextDialog(true);
@@ -280,4 +282,4 @@ Replacer::onReplace(const QString &text, int replacementIndex, int replacedLengt
 	}
 }
 
-#include "replacer.moc"
+
