@@ -1,30 +1,32 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "speller.h"
 #include "../application.h"
-#include "../configs/spellingconfig.h"
 #include "../../core/subtitleiterator.h"
 
-#include <KDebug>
-#include <KLocale>
+#include <QDebug>
+
 #include <KMessageBox>
+#include <KLocalizedString>
+
 #include <sonnet/dialog.h>
 #include <sonnet/backgroundchecker.h>
 
@@ -38,7 +40,7 @@ Speller::Speller(QWidget *parent) :
 	m_sonnetDialog(0),
 	m_iterator(0)
 {
-	connect(app()->spellingConfig(), SIGNAL(optionChanged(const QString &, const QString &)), this, SLOT(onSpellingOptionChanged(const QString &, const QString &)));
+	connect(SCConfig::self(), SIGNAL(configChanged()), this, SLOT(onConfigChanged()));
 }
 
 Speller::~Speller()
@@ -113,10 +115,10 @@ Speller::onBufferDone()
 	if(advance()) {
 		if(m_translationMode) {
 			m_feedPrimaryNext = !m_feedPrimaryNext;
-			m_sonnetDialog->setBuffer(m_feedPrimaryNext ? m_iterator->current()->secondaryText().string() : m_iterator->current()->primaryText().string()
-			                          );
-		} else
+			m_sonnetDialog->setBuffer(m_feedPrimaryNext ? m_iterator->current()->secondaryText().string() : m_iterator->current()->primaryText().string());
+		} else {
 			m_sonnetDialog->setBuffer(m_iterator->current()->primaryText().string());
+		}
 	}
 }
 
@@ -132,8 +134,7 @@ Speller::advance()
 		if(m_iterator->index() < 0) {
 			m_iterator->toFirst();
 
-			if(KMessageBox::warningContinueCancel(parentWidget(), i18n("End of subtitle reached.\nContinue from the beginning?"), i18n("Spell Checking")
-			                                      ) != KMessageBox::Continue)
+			if(KMessageBox::Continue != KMessageBox::warningContinueCancel(parentWidget(), i18n("End of subtitle reached.\nContinue from the beginning?"), i18n("Spell Checking")))
 				return false;
 		}
 	}
@@ -152,25 +153,24 @@ Speller::onMisspelling(const QString &before, int pos)
 void
 Speller::onCorrected(const QString &before, int pos, const QString &after)
 {
+	if(before == after)
+		return;
+
 	if(m_translationMode && m_feedPrimaryNext)
-		m_iterator->current()->setSecondaryText(SString(m_iterator->current()->secondaryText()).replace(pos, before.length(), after)
-		                                        );
+		m_iterator->current()->setSecondaryText(SString(m_iterator->current()->secondaryText()).replace(pos, before.length(), after));
 	else
-		m_iterator->current()->setPrimaryText(SString(m_iterator->current()->primaryText()).replace(pos, before.length(), after)
-		                                      );
+		m_iterator->current()->setPrimaryText(SString(m_iterator->current()->primaryText()).replace(pos, before.length(), after));
 }
 
 void
-Speller::onSpellingOptionChanged(const QString &option, const QString & /*value */)
+Speller::onConfigChanged()
 {
-	if(option == SpellingConfig::keyDefaultLanguage()) {
-		if(m_sonnetDialog) {
-			invalidate();
+	if(m_sonnetDialog) {
+		invalidate();
 
-			m_sonnetDialog->deleteLater();
-			m_sonnetDialog = 0;
-		}
+		m_sonnetDialog->deleteLater();
+		m_sonnetDialog = 0;
 	}
 }
 
-#include "speller.moc"
+
