@@ -1,44 +1,44 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "simplerichtextedit.h"
 
 #include "../main/dialogs/subtitlecolordialog.h"
 
-#include <QtCore/QRegExp>
-#include <QtCore/QEvent>
-#include <QtGui/QMenu>
-#include <QtGui/QShortcutEvent>
-#include <QtGui/QContextMenuEvent>
-#include <QtGui/QFocusEvent>
-#include <QtGui/QKeyEvent>
+#include <QRegExp>
+#include <QEvent>
+#include <QMenu>
+#include <QShortcutEvent>
+#include <QContextMenuEvent>
+#include <QFocusEvent>
+#include <QKeyEvent>
+#include <QAction>
+#include <QMenu>
+#include <QIcon>
+#include <QDebug>
 
-#include <KDebug>
-#include <KLocale>
-#include <KMenu>
-#include <KIcon>
 #include <KStandardShortcut>
+#include <KLocalizedString>
 
-#include <KAction>
-
-SimpleRichTextEdit::SimpleRichTextEdit(QWidget *parent) :
-	KTextEdit(parent)
+SimpleRichTextEdit::SimpleRichTextEdit(QWidget *parent)
+	: KTextEdit(parent)
 {
 	enableFindReplace(false);
 	setCheckSpellingEnabled(true);
@@ -62,98 +62,101 @@ SimpleRichTextEdit::SimpleRichTextEdit(QWidget *parent) :
 
 	setTextInteractionFlags(Qt::TextEditorInteraction);
 
-	m_actions[Undo] = new KAction(this);
-	m_actions[Undo]->setIcon(KIcon("edit-undo"));
+	m_actions[Undo] = new QAction(this);
+	m_actions[Undo]->setIcon(QIcon::fromTheme("edit-undo"));
 	m_actions[Undo]->setText(i18n("Undo"));
-	m_actions[Undo]->setShortcut(KStandardShortcut::undo(), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[Undo]->setShortcuts(KStandardShortcut::undo());
 	connect(m_actions[Undo], SIGNAL(triggered()), this, SLOT(undo()));
 
-	m_actions[Redo] = new KAction(this);
-	m_actions[Redo]->setIcon(KIcon("edit-redo"));
+	m_actions[Redo] = new QAction(this);
+	m_actions[Redo]->setIcon(QIcon::fromTheme("edit-redo"));
 	m_actions[Redo]->setText(i18n("Redo"));
-	m_actions[Redo]->setShortcut(KStandardShortcut::redo(), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[Redo]->setShortcuts(KStandardShortcut::redo());
 	connect(m_actions[Redo], SIGNAL(triggered()), this, SLOT(redo()));
 
-	m_actions[Cut] = new KAction(this);
-	m_actions[Cut]->setIcon(KIcon("edit-cut"));
+	m_actions[Cut] = new QAction(this);
+	m_actions[Cut]->setIcon(QIcon::fromTheme("edit-cut"));
 	m_actions[Cut]->setText(i18n("Cut"));
-	m_actions[Cut]->setShortcut(KStandardShortcut::cut(), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[Cut]->setShortcuts(KStandardShortcut::cut());
 	connect(m_actions[Cut], SIGNAL(triggered()), this, SLOT(cut()));
 
-	m_actions[Copy] = new KAction(this);
-	m_actions[Copy]->setIcon(KIcon("edit-copy"));
+	m_actions[Copy] = new QAction(this);
+	m_actions[Copy]->setIcon(QIcon::fromTheme("edit-copy"));
 	m_actions[Copy]->setText(i18n("Copy"));
-	m_actions[Copy]->setShortcut(KStandardShortcut::copy(), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[Copy]->setShortcuts(KStandardShortcut::copy());
 	connect(m_actions[Copy], SIGNAL(triggered()), this, SLOT(copy()));
 
-	m_actions[Paste] = new KAction(this);
-	m_actions[Paste]->setIcon(KIcon("edit-paste"));
+#if !defined(QT_NO_CLIPBOARD)
+	m_actions[Paste] = new QAction(this);
+	m_actions[Paste]->setIcon(QIcon::fromTheme("edit-paste"));
 	m_actions[Paste]->setText(i18n("Paste"));
-	m_actions[Paste]->setShortcut(KStandardShortcut::paste(), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[Paste]->setShortcuts(KStandardShortcut::paste());
 	connect(m_actions[Paste], SIGNAL(triggered()), this, SLOT(paste()));
+#endif
 
-	m_actions[Delete] = new KAction(this);
-	m_actions[Delete]->setIcon(KIcon("edit-delete"));
+	m_actions[Delete] = new QAction(this);
+	m_actions[Delete]->setIcon(QIcon::fromTheme("edit-delete"));
 	m_actions[Delete]->setText(i18n("Delete"));
-	m_actions[Delete]->setShortcut(QKeySequence::Delete, KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[Delete]->setShortcut(QKeySequence::Delete);
 	connect(m_actions[Delete], SIGNAL(triggered()), this, SLOT(deleteText()));
 
-	m_actions[Clear] = new KAction(this);
-	m_actions[Clear]->setIcon(KIcon("edit-clear"));
+	m_actions[Clear] = new QAction(this);
+	m_actions[Clear]->setIcon(QIcon::fromTheme("edit-clear"));
 	m_actions[Clear]->setText(i18nc("@action:inmenu Clear all text", "Clear"));
 	connect(m_actions[Clear], SIGNAL(triggered()), this, SLOT(undoableClear()));
 
-	m_actions[SelectAll] = new KAction(this);
-	m_actions[SelectAll]->setIcon(KIcon("edit-select-all"));
+	m_actions[SelectAll] = new QAction(this);
+	m_actions[SelectAll]->setIcon(QIcon::fromTheme("edit-select-all"));
 	m_actions[SelectAll]->setText(i18n("Select All"));
-	m_actions[SelectAll]->setShortcut(QKeySequence::SelectAll, KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[SelectAll]->setShortcut(QKeySequence::SelectAll);
 	connect(m_actions[SelectAll], SIGNAL(triggered()), this, SLOT(selectAll()));
 
-	m_actions[ToggleBold] = new KAction(this);
-	m_actions[ToggleBold]->setIcon(KIcon("format-text-bold"));
+	m_actions[ToggleBold] = new QAction(this);
+	m_actions[ToggleBold]->setIcon(QIcon::fromTheme("format-text-bold"));
 	m_actions[ToggleBold]->setText(i18nc("@action:inmenu Toggle bold style", "Bold"));
-	m_actions[ToggleBold]->setShortcut(KShortcut("Ctrl+B"), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[ToggleBold]->setShortcut(QKeySequence("Ctrl+B"));
 	connect(m_actions[ToggleBold], SIGNAL(triggered()), this, SLOT(toggleFontBold()));
 
-	m_actions[ToggleItalic] = new KAction(this);
-	m_actions[ToggleItalic]->setIcon(KIcon("format-text-italic"));
+	m_actions[ToggleItalic] = new QAction(this);
+	m_actions[ToggleItalic]->setIcon(QIcon::fromTheme("format-text-italic"));
 	m_actions[ToggleItalic]->setText(i18nc("@action:inmenu Toggle italic style", "Italic"));
-	m_actions[ToggleItalic]->setShortcut(KShortcut("Ctrl+I"), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[ToggleItalic]->setShortcut(QKeySequence("Ctrl+I"));
 	connect(m_actions[ToggleItalic], SIGNAL(triggered()), this, SLOT(toggleFontItalic()));
 
-	m_actions[ToggleUnderline] = new KAction(this);
-	m_actions[ToggleUnderline]->setIcon(KIcon("format-text-underline"));
+	m_actions[ToggleUnderline] = new QAction(this);
+	m_actions[ToggleUnderline]->setIcon(QIcon::fromTheme("format-text-underline"));
 	m_actions[ToggleUnderline]->setText(i18nc("@action:inmenu Toggle underline style", "Underline"));
-	m_actions[ToggleUnderline]->setShortcut(KShortcut("Ctrl+U"), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[ToggleUnderline]->setShortcut(QKeySequence("Ctrl+U"));
 	connect(m_actions[ToggleUnderline], SIGNAL(triggered()), this, SLOT(toggleFontUnderline()));
 
-	m_actions[ToggleStrikeOut] = new KAction(this);
-	m_actions[ToggleStrikeOut]->setIcon(KIcon("format-text-strikethrough"));
+	m_actions[ToggleStrikeOut] = new QAction(this);
+	m_actions[ToggleStrikeOut]->setIcon(QIcon::fromTheme("format-text-strikethrough"));
 	m_actions[ToggleStrikeOut]->setText(i18nc("@action:inmenu Toggle strike through style", "Strike Through"));
-	m_actions[ToggleStrikeOut]->setShortcut(KShortcut("Ctrl+T"), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[ToggleStrikeOut]->setShortcut(QKeySequence("Ctrl+T"));
 	connect(m_actions[ToggleStrikeOut], SIGNAL(triggered()), this, SLOT(toggleFontStrikeOut()));
 
-	m_actions[ChangeTextColor] = new KAction(this);
-	m_actions[ChangeTextColor]->setIcon(KIcon("format-text-color"));
+	m_actions[ChangeTextColor] = new QAction(this);
+	m_actions[ChangeTextColor]->setIcon(QIcon::fromTheme("format-text-color"));
 	m_actions[ChangeTextColor]->setText(i18nc("@action:inmenu Change Text Color", "Text Color"));
-	m_actions[ChangeTextColor]->setShortcut(KShortcut("Ctrl+Shift+C"), KAction::DefaultShortcut | KAction::ActiveShortcut);
+	m_actions[ChangeTextColor]->setShortcut(QKeySequence("Ctrl+Shift+C"));
 	connect(m_actions[ChangeTextColor], SIGNAL(triggered()), this, SLOT(changeTextColor()));
 
-	m_actions[CheckSpelling] = new KAction(this);
-	m_actions[CheckSpelling]->setIcon(KIcon("tools-check-spelling"));
+	m_actions[CheckSpelling] = new QAction(this);
+	m_actions[CheckSpelling]->setIcon(QIcon::fromTheme("tools-check-spelling"));
 	m_actions[CheckSpelling]->setText(i18n("Check Spelling..."));
 	connect(m_actions[CheckSpelling], SIGNAL(triggered()), this, SLOT(checkSpelling()));
 
-	m_actions[ToggleAutoSpellChecking] = new KAction(this);
+	m_actions[ToggleAutoSpellChecking] = new QAction(this);
 	m_actions[ToggleAutoSpellChecking]->setText(i18n("Auto Spell Check"));
 	m_actions[ToggleAutoSpellChecking]->setCheckable(true);
 	connect(m_actions[ToggleAutoSpellChecking], SIGNAL(triggered()), this, SLOT(toggleAutoSpellChecking()));
 
-	m_actions[AllowTabulations] = new KAction(this);
+	m_actions[AllowTabulations] = new QAction(this);
 	m_actions[AllowTabulations]->setText(i18n("Allow Tabulations"));
 	connect(m_actions[AllowTabulations], SIGNAL(triggered()), this, SLOT(toggleTabChangesFocus()));
 
-	QMenu *menu = QTextEdit::createStandardContextMenu();   // krazy:exclude=c++/qclasses
+	QMenu *menu = createStandardContextMenu();
+	menu->setParent(this);
 	QList<QAction *> actions = menu->actions();
 	m_insertUnicodeControlCharMenu = 0;
 	for(QList<QAction *>::ConstIterator it = actions.constBegin(), end = actions.constEnd(); it != end; ++it) {
@@ -174,15 +177,15 @@ SimpleRichTextEdit::~SimpleRichTextEdit()
 		delete m_insertUnicodeControlCharMenu->parent();
 }
 
-KAction *
+QAction *
 SimpleRichTextEdit::action(int action) const
 {
 	return action >= 0 && action < ActionCount ? m_actions[action] : 0;
 }
 
-QList<KAction *> SimpleRichTextEdit::actions() const
+QList<QAction *> SimpleRichTextEdit::actions() const
 {
-	QList<KAction *> actions;
+	QList<QAction *> actions;
 	for(int index = 0; index < ActionCount; ++index)
 		actions.append(m_actions[index]);
 	return actions;
@@ -456,10 +459,9 @@ SimpleRichTextEdit::createContextMenu(const QPoint &mouseGlobalPos)
 	QTextDocument *document = this->document();
 	QTextCursor cursor = textCursor();
 
-	const bool showTextSelectionActions = (Qt::TextEditable | Qt::TextSelectableByKeyboard | Qt::TextSelectableByMouse)
-	                                      & interactionFlags;
+	const bool showTextSelectionActions = (Qt::TextEditable | Qt::TextSelectableByKeyboard | Qt::TextSelectableByMouse) & interactionFlags;
 
-	KMenu *menu = new KMenu(this);
+	QMenu *menu = new QMenu(this);
 
 	if(interactionFlags & Qt::TextEditable) {
 		m_actions[Undo]->setEnabled(document->isUndoAvailable());
@@ -585,7 +587,7 @@ SimpleRichTextEdit::event(QEvent *event)
 		QKeySequence key(keyEvent->modifiers() + keyEvent->key());
 
 		for(int index = 0; index < ActionCount; ++index) {
-			if(m_actions[index]->shortcut().contains(key)) {
+			if(m_actions[index]->shortcut().matches(key) == QKeySequence::ExactMatch) {
 				event->accept();
 				return true;
 			}
@@ -601,7 +603,7 @@ SimpleRichTextEdit::keyPressEvent(QKeyEvent *event)
 	QKeySequence key(event->modifiers() + event->key());
 
 	for(int index = 0; index < ActionCount; ++index) {
-		if(m_actions[index]->shortcut().contains(key)) {
+		if(m_actions[index]->shortcut().matches(key) == QKeySequence::ExactMatch) {
 			m_actions[index]->trigger();
 			return;
 		}
@@ -610,4 +612,4 @@ SimpleRichTextEdit::keyPressEvent(QKeyEvent *event)
 	KTextEdit::keyPressEvent(event);
 }
 
-#include "simplerichtextedit.moc"
+
