@@ -1,36 +1,38 @@
-/***************************************************************************
- *   Copyright (C) 2007-2009 Sergio Pistone (sergio_pistone@yahoo.com.ar)  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/**
+ * Copyright (C) 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
+ * Copyright (C) 2010-2015 Mladen Milinkovic <max@smoothware.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 #include "textoverlaywidget.h"
 
-#include <QtCore/QCoreApplication>
-#include <QtGui/QPainter>
-#include <QtGui/QTextDocument>
-#include <QtGui/QAbstractTextDocumentLayout>
-#include <QtGui/QResizeEvent>
+#include <QCoreApplication>
+#include <QPainter>
+#include <QTextDocument>
+#include <QAbstractTextDocumentLayout>
+#include <QResizeEvent>
 
 #include "../profiler.h"
-#include <KDebug>
+#include <QDebug>
 
 TextOverlayWidget::TextOverlayWidget(QWidget *parent) :
 	QWidget(parent, 0),
 	m_text(),
+	m_antialias(false),
 	m_alignment(Qt::AlignVCenter | Qt::AlignHCenter),
 	m_font(),
 	m_primaryColor(Qt::yellow),
@@ -43,16 +45,12 @@ TextOverlayWidget::TextOverlayWidget(QWidget *parent) :
 	m_textDocument(new QTextDocument()),
 	m_dirty(true)
 {
-	// NOTE: this is only supported in X11 but if we don't enable it,
-	// setting the widget mask causes a very disgusting flicker.
-	// Hopefully the flicker won't be present on other platforms...
-	setAttribute(Qt::WA_PaintOnScreen, true);
 	setAttribute(Qt::WA_StaticContents, true);
 	setAttribute(Qt::WA_OpaquePaintEvent, true);
 	setAttribute(Qt::WA_NoSystemBackground, true);
 
 	m_font.setPointSize(15);
-	m_font.setStyleStrategy(QFont::NoAntialias);
+	m_font.setStyleStrategy(m_antialias ? QFont::PreferAntialias : QFont::NoAntialias);
 	m_textDocument->setDefaultFont(m_font);
 
 	QTextOption textOption;
@@ -207,6 +205,17 @@ TextOverlayWidget::setOutlineWidth(int width)
 	}
 }
 
+void
+TextOverlayWidget::setAntialias(bool antialias)
+{
+	if(m_antialias != antialias) {
+		m_antialias = antialias;
+		m_font.setStyleStrategy(m_antialias ? QFont::PreferAntialias : QFont::NoAntialias);
+		m_textDocument->setDefaultFont(m_font);
+		setDirty(false, false);
+	}
+}
+
 QColor
 TextOverlayWidget::outlineColor() const
 {
@@ -358,8 +367,7 @@ TextOverlayWidget::updateContents()
 
 		QPainter painter(&m_bgImage);
 
-		// Disable rendering hints to (hopefully) improve performance
-		painter.setRenderHints(QPainter::Antialiasing | QPainter::TextAntialiasing | QPainter::SmoothPixmapTransform | QPainter::HighQualityAntialiasing | QPainter::NonCosmeticDefaultPen, false);
+		painter.setRenderHints(QPainter::Antialiasing | QPainter::TextAntialiasing | QPainter::SmoothPixmapTransform | QPainter::HighQualityAntialiasing | QPainter::NonCosmeticDefaultPen, m_antialias);
 
 		painter.fillRect(rect, m_transColor);
 		painter.setFont(m_font);
@@ -367,19 +375,36 @@ TextOverlayWidget::updateContents()
 		painter.translate(0, 0);
 		QAbstractTextDocumentLayout::PaintContext context;
 		context.palette = palette();
+
+		if(m_outlineWidth > 0) {
+			// remove custom color info from document
+			QTextCharFormat fmt;
+			fmt.setForeground(QBrush(m_outlineColor));
+			QTextCursor cur(m_textDocument);
+			cur.select(QTextCursor::Document);
+			cur.mergeCharFormat(fmt);
+
+			context.palette.setColor(QPalette::Text, m_outlineColor);
+			m_textDocument->documentLayout()->draw(&painter, context);
+			setOutline();
+
+			// restore custom color info
+			m_textDocument->undo();
+		}
+
 		context.palette.setColor(QPalette::Text, m_primaryColor);
 		m_textDocument->documentLayout()->draw(&painter, context);
 
 		painter.end();
 
-		setMaskAndOutline(m_outlineWidth);
+		setMonoMask();
 	}
 
 	m_dirty = false;
 }
 
 void
-TextOverlayWidget::setMaskAndOutline(int outlineWidth)
+TextOverlayWidget::setMonoMask()
 {
 	static const QRgb color0 = QColor(Qt::color0).rgb();    // mask transparent
 	static const QRgb color1 = QColor(Qt::color1).rgb();    // mask non transparent
@@ -390,58 +415,77 @@ TextOverlayWidget::setMaskAndOutline(int outlineWidth)
 	QImage maskImage(size, QImage::Format_RGB32);
 	maskImage.fill(color0);
 
-	if(outlineWidth > 0) {
-		const int maxX = size.width() - 1;
-		const int maxY = size.height() - 1;
+	QRgb *bgImageBits = (QRgb *)m_bgImage.bits();
+	QRgb *maskImageBits = (QRgb *)maskImage.bits();
 
-		QRgb *bgImageScanLines[size.height()];
-		QRgb *maskImageScanLines[size.height()];
-
-		// we don't need all the values initialized, only the ones we will actually use
-		for(int y = 0; y <= maxY; ++y) {
-			bgImageScanLines[y] = (QRgb *)m_bgImage.scanLine(y);
-			maskImageScanLines[y] = (QRgb *)maskImage.scanLine(y);
-		}
-
-		int lminX, lmaxX, lminY, lmaxY;
-		for(int y = 0; y <= maxY; ++y) {
-			for(int x = 0; x <= maxX; ++x) {
-				if(bgImageScanLines[y][x] == m_primaryRGB) {    // draw the outline
-					lminY = y - outlineWidth;
-					if(lminY < 0)
-						lminY = 0;
-					lmaxY = y + outlineWidth;
-					if(lmaxY > maxY)
-						lmaxY = maxY;
-
-					lminX = x - outlineWidth;
-					if(lminX < 0)
-						lminX = 0;
-					lmaxX = x + outlineWidth;
-					if(lmaxX > maxX)
-						lmaxX = maxX;
-
-					for(int ly = lminY; ly <= lmaxY; ++ly) {
-						for(int lx = lminX; lx <= lmaxX; ++lx) {
-							maskImageScanLines[ly][lx] = color1;
-							if(bgImageScanLines[ly][lx] != m_primaryRGB)
-								bgImageScanLines[ly][lx] = m_outlineRGB;
-						}
-					}
-				}
-			}
-		}
-	} else {
-		QRgb *bgImageBits = (QRgb *)m_bgImage.bits();
-		QRgb *maskImageBits = (QRgb *)maskImage.bits();
-
-		for(int index = 0, count = size.width() * size.height(); index < count; ++index) {
-			if(bgImageBits[index] != m_transRGB)
-				maskImageBits[index] = color1;
-		}
+	for(int index = 0, count = size.width() * size.height(); index < count; ++index) {
+		if(bgImageBits[index] != m_transRGB)
+			maskImageBits[index] = color1;
 	}
 
 	setMask(QBitmap::fromImage(maskImage, Qt::MonoOnly));
 }
 
-#include "textoverlaywidget.moc"
+void
+TextOverlayWidget::setOutline()
+{
+	if(!m_outlineWidth)
+		return;
+
+	const QSize size = this->size();
+	const int maxX = size.width() - 1;
+	const int maxY = size.height() - 1;
+
+	QRgb *bgImageScanLines[size.height()];
+
+	for(int y = 0; y <= maxY; y++)
+		bgImageScanLines[y] = (QRgb *)m_bgImage.scanLine(y);
+
+	QRgb *cc, *cd;
+	for(int y = 0; y <= maxY; y++) {
+		for(int x = m_outlineWidth; x <= maxX; x++) {
+			int ix = maxX - x;
+			for(int d = 1; d <= m_outlineWidth; d++) {
+				// left to right
+				cd = &bgImageScanLines[y][x - d];
+				if(*cd != m_outlineRGB) {
+					cc = &bgImageScanLines[y][x];
+					if(*cc != m_transRGB)
+						*cd = *cc;
+				}
+				// right to left
+				cd = &bgImageScanLines[y][ix + d];
+				if(*cd != m_outlineRGB) {
+					cc = &bgImageScanLines[y][ix];
+					if(*cc != m_transRGB)
+						*cd = *cc;
+				}
+			}
+		}
+	}
+
+	for(int x = 0; x <= maxX; x++) {
+		for(int y = m_outlineWidth; y <= maxY; y++) {
+			int iy = maxY - y;
+			for(int d = 1; d <= m_outlineWidth; d++) {
+				// top to bottom
+				cd = &bgImageScanLines[y - d][x];
+				if(*cd != m_outlineRGB) {
+					cc = &bgImageScanLines[y][x];
+					if(*cc != m_transRGB)
+						*cd = *cc;
+				}
+				// bottom to top
+				cd = &bgImageScanLines[iy + d][x];
+				if(*cd != m_outlineRGB) {
+					cc = &bgImageScanLines[iy][x];
+					if(*cc != m_transRGB)
+						*cd = *cc;
+				}
+			}
+		}
+	}
+
+}
+
+
