@@ -24,9 +24,9 @@
 #include <config.h>
 #endif
 
-#include <QtGui/QTimeEdit>
+#include <QTimeEdit>
 
-class QEvent;
+QT_FORWARD_DECLARE_CLASS(QEvent)
 
 class TimeEdit : public QTimeEdit
 {
