@@ -24,8 +24,8 @@
 #include <config.h>
 #endif
 
-#include <QtCore/QString>
-#include <QtGui/QValidator>
+#include <QString>
+#include <QValidator>
 
 // class TimeValidator : public QRegExpValidator
 class TimeValidator : public QValidator
