@@ -33,6 +33,7 @@
 
 #include <QProgressBar>
 #include <QLabel>
+#include <QMenu>
 #include <QBoxLayout>
 #include <QToolButton>
 #include <QScrollBar>
@@ -55,6 +56,7 @@ WaveformWidget::WaveformWidget(QWidget *parent)
 	  m_timeStart(0.),
 	  m_timeCurrent(0.),
 	  m_timeEnd(MAX_WINDOW_ZOOM),
+	  m_RMBDown(false),
 	  m_scrollBar(Q_NULLPTR),
 	  m_autoScroll(true),
 	  m_userScroll(false),
@@ -316,11 +318,24 @@ WaveformWidget::updateZoomData()
 void
 WaveformWidget::setSubtitle(Subtitle *subtitle)
 {
+	if(m_subtitle)
+		disconnect(m_subtitle, &Subtitle::primaryChanged, this, &WaveformWidget::onSubtitleChanged);
+
 	m_subtitle = subtitle;
 
-	m_visibleLines.clear();
-	m_visibleLinesDirty = subtitle != Q_NULLPTR;
+	if(m_subtitle)
+		connect(m_subtitle, &Subtitle::primaryChanged, this, &WaveformWidget::onSubtitleChanged);
 
+	m_visibleLines.clear();
+	m_visibleLinesDirty = true;
+
+	m_waveformGraphics->update();
+}
+
+void
+WaveformWidget::onSubtitleChanged()
+{
+	m_visibleLinesDirty = true;
 	m_waveformGraphics->update();
 }
 
@@ -543,12 +558,25 @@ WaveformWidget::paintGraphics(QPainter &painter)
 			painter.setPen(m_subNumberColor);
 			painter.setFont(m_fontNumber);
 			if(m_vertical)
-				painter.drawText(m_fontNumberHeight / 2, showY + m_fontNumberHeight + 2, QString::number(sub->index()));
+				painter.drawText(m_fontNumberHeight / 2, showY + m_fontNumberHeight + 2, QString::number(sub->index() + 1));
 			else
-				painter.drawText(showY + m_fontNumberHeight / 2, m_fontNumberHeight + 2, QString::number(sub->index()));
+				painter.drawText(showY + m_fontNumberHeight / 2, m_fontNumberHeight + 2, QString::number(sub->index() + 1));
 		}
 	}
 
+	if(m_RMBDown) {
+		int showY = widgetSpan * (m_timeRMBPress.toMillis() - m_timeStart.toMillis()) / msWindowSize;
+		int hideY = widgetSpan * (m_timeRMBRelease.toMillis() - m_timeStart.toMillis()) / msWindowSize;
+
+		QRect box;
+		if(m_vertical)
+			box = QRect(0, showY + m_subBorderWidth, widgetWidth, hideY - showY - 2 * m_subBorderWidth);
+		else
+			box = QRect(showY + m_subBorderWidth, 0, hideY - showY - 2 * m_subBorderWidth, widgetHeight);
+
+		painter.fillRect(box, m_selectedBack);
+	}
+
 	int playY = widgetSpan * (m_timeCurrent - m_timeStart).toMillis() / msWindowSize;
 	painter.setPen(m_playColor);
 	if(m_vertical)
@@ -620,10 +648,14 @@ WaveformWidget::resizeEvent(QResizeEvent *event)
 /*virtual*/ void
 WaveformWidget::leaveEvent(QEvent */*event*/)
 {
+	m_pointerTime.setMillisTime(Time::MaxMseconds);
+
 	if(m_userScroll) {
 		m_userScroll = false;
 		if(m_autoScroll)
 			onPlayerPositionChanged(m_timeCurrent.toSeconds());
+	} else {
+		m_waveformGraphics->update();
 	}
 }
 
@@ -635,9 +667,9 @@ WaveformWidget::eventFilter(QObject *obj, QEvent *event)
 
 	switch(event->type()) {
 	case QEvent::Wheel: {
-		QPoint delta = reinterpret_cast<QWheelEvent *>(event)->angleDelta() / 8;
+		QPoint delta = static_cast<QWheelEvent *>(event)->angleDelta() / 8;
 		if(delta.isNull())
-			delta = reinterpret_cast<QWheelEvent *>(event)->pixelDelta();
+			delta = static_cast<QWheelEvent *>(event)->pixelDelta();
 		if(delta.isNull())
 			return false;
 
@@ -660,17 +692,20 @@ WaveformWidget::eventFilter(QObject *obj, QEvent *event)
 	switch(event->type()) {
 	case QEvent::Paint: {
 		QPainter painter(m_waveformGraphics);
-		painter.fillRect(reinterpret_cast<QPaintEvent *>(event)->rect(), Qt::black);
+		painter.fillRect(static_cast<QPaintEvent *>(event)->rect(), Qt::black);
 		paintGraphics(painter);
 		return true;
 	}
 
 	case QEvent::MouseMove: {
-		QMouseEvent *mouse = reinterpret_cast<QMouseEvent *>(event);
+		QMouseEvent *mouse = static_cast<QMouseEvent *>(event);
 		int y = m_vertical ? mouse->y() : mouse->x();
 
 		m_pointerTime = timeAt(y);
 
+		if(m_RMBDown)
+			m_timeRMBRelease = m_pointerTime;
+
 		if(m_draggedLine) {
 			m_draggedTime = m_pointerTime;
 		} else {
@@ -692,17 +727,24 @@ WaveformWidget::eventFilter(QObject *obj, QEvent *event)
 	}
 
 	case QEvent::MouseButtonDblClick: {
-		QMouseEvent *mouse = reinterpret_cast<QMouseEvent *>(event);
+		QMouseEvent *mouse = static_cast<QMouseEvent *>(event);
 		emit doubleClick(timeAt(m_vertical ? mouse->y() : mouse->x()));
 		return true;
 	}
 
 	case QEvent::MouseButtonPress: {
-		QMouseEvent *mouse = reinterpret_cast<QMouseEvent *>(event);
+		QMouseEvent *mouse = static_cast<QMouseEvent *>(event);
+		int y = m_vertical ? mouse->y() : mouse->x();
+
+		if(mouse->button() == Qt::RightButton) {
+			m_timeRMBPress = timeAt(y);
+			m_RMBDown = true;
+			return false;
+		}
+
 		if(mouse->button() != Qt::LeftButton)
 			return false;
 
-		int y = m_vertical ? mouse->y() : mouse->x();
 		m_draggedPos = subtitleAt(y, &m_draggedLine);
 		if(m_draggedLine && !m_subtitle->anchoredLines().empty() && m_subtitle->anchoredLines().indexOf(m_draggedLine) == -1) {
 			m_draggedTime = 0.;
@@ -724,12 +766,21 @@ WaveformWidget::eventFilter(QObject *obj, QEvent *event)
 	}
 
 	case QEvent::MouseButtonRelease: {
-		QMouseEvent *mouse = reinterpret_cast<QMouseEvent *>(event);
+		QMouseEvent *mouse = static_cast<QMouseEvent *>(event);
+		int y = m_vertical ? mouse->y() : mouse->x();
+
+		if(mouse->button() == Qt::RightButton) {
+			m_timeRMBRelease = timeAt(y);
+			m_RMBDown = false;
+			showContextMenu(mouse);
+			return false;
+		}
+
 		if(mouse->button() != Qt::LeftButton)
 			return false;
 
 		if(m_draggedLine) {
-			m_draggedTime = timeAt(m_vertical ? mouse->y() : mouse->x());
+			m_draggedTime = timeAt(y);
 			if(m_draggedPos == DRAG_LINE) {
 				m_draggedLine->setHideTime(m_draggedTime - m_draggedOffset + m_draggedLine->durationTime());
 				m_draggedLine->setShowTime(m_draggedTime - m_draggedOffset);
@@ -841,3 +892,18 @@ WaveformWidget::createToolButton(const QString &actionName, int iconSize)
 	toolButton->setFocusPolicy(Qt::NoFocus);
 	return toolButton;
 }
+
+void
+WaveformWidget::showContextMenu(QMouseEvent *event)
+{
+	static QMenu *menu = nullptr;
+
+	if(!menu) {
+		menu = new QMenu(this);
+		menu->addAction(app()->action(ACT_WAVEFORM_SET_CURRENT_LINE_SHOW_TIME));
+		menu->addAction(app()->action(ACT_WAVEFORM_SET_CURRENT_LINE_HIDE_TIME));
+		menu->addAction(app()->action(ACT_WAVEFORM_INSERT_LINE));
+	}
+
+	menu->popup(event->globalPos());
+}
